# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.



from bambou import NURESTObject


class NUNSGInfo(NURESTObject):
    """ Represents a NSGInfo in the VSD

        Notes:
            Device information coming from the NSG.  That includes the hardware type of the NSG (CPU, memory, family), the version of BIOS, build information, and software application packages installed.
    """

    __rest_name__ = "nsginfo"
    __resource_name__ = "nsginfos"

    
    ## Constants
    
    CONST_FAMILY_NSG_C = "NSG_C"
    
    CONST_FAMILY_NSG_E = "NSG_E"
    
    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
    
    CONST_BOOTSTRAP_STATUS_NOTIFICATION_APP_REQ_SENT = "NOTIFICATION_APP_REQ_SENT"
    
    CONST_PERSONALITY_NSGDUC = "NSGDUC"
    
    CONST_FAMILY_NSG_V = "NSG_V"
    
    CONST_BOOTSTRAP_STATUS_ACTIVE = "ACTIVE"
    
    CONST_CMD_STATUS_RUNNING = "RUNNING"
    
    CONST_FAMILY_NSG_X = "NSG_X"
    
    CONST_FAMILY_NSG_DOCKER = "NSG_DOCKER"
    
    CONST_FAMILY_NSG_E200 = "NSG_E200"
    
    CONST_CMD_STATUS_COMPLETED = "COMPLETED"
    
    CONST_PERSONALITY_NSG = "NSG"
    
    CONST_CMD_STATUS_FAILED = "FAILED"
    
    CONST_BOOTSTRAP_STATUS_CERTIFICATE_SIGNED = "CERTIFICATE_SIGNED"
    
    CONST_FAMILY_NSG_AZ = "NSG_AZ"
    
    CONST_FAMILY_ANY = "ANY"
    
    CONST_CMD_STATUS_SKIPPED = "SKIPPED"
    
    CONST_BOOTSTRAP_STATUS_NOTIFICATION_APP_REQ_ACK = "NOTIFICATION_APP_REQ_ACK"
    
    CONST_CMD_STATUS_UNKNOWN = "UNKNOWN"
    
    CONST_FAMILY_NSG_X200 = "NSG_X200"
    
    CONST_FAMILY_NSG_E300 = "NSG_E300"
    
    CONST_CMD_TYPE_NSG_UPGRADE_TO_IMAGE = "NSG_UPGRADE_TO_IMAGE"
    
    CONST_CMD_STATUS_STARTED = "STARTED"
    
    CONST_FAMILY_NSG_AMI = "NSG_AMI"
    
    CONST_CMD_STATUS_ABANDONED = "ABANDONED"
    
    CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
    
    CONST_CMD_TYPE_NSG_DOWNLOAD_OS_IMAGE = "NSG_DOWNLOAD_OS_IMAGE"
    
    CONST_BOOTSTRAP_STATUS_INACTIVE = "INACTIVE"
    
    CONST_PERSONALITY_NSGBR = "NSGBR"
    
    

    def __init__(self, **kwargs):
        """ Initializes a NSGInfo instance

            Notes:
                You can specify all parameters while calling this methods.
                A special argument named `data` will enable you to load the
                object from a Python dictionary

            Examples:
                >>> nsginfo = NUNSGInfo(id=u'xxxx-xxx-xxx-xxx', name=u'NSGInfo')
                >>> nsginfo = NUNSGInfo(data=my_dict)
        """

        super(NUNSGInfo, self).__init__()

        # Read/Write Attributes
        
        self._mac_address = None
        self._ca_certificate = None
        self._aar_application_release_date = None
        self._aar_application_version = None
        self._bios_release_date = None
        self._bios_version = None
        self._sku = None
        self._tpm_status = None
        self._tpm_version = None
        self._cpu_core_allocation = None
        self._cpu_type = None
        self._nsg_version = None
        self._uuid = None
        self._name = None
        self._family = None
        self._patches_detail = None
        self._serial_number = None
        self._personality = None
        self._certificate = None
        self._libraries = None
        self._cmd_detailed_status = None
        self._cmd_detailed_status_code = None
        self._cmd_download_progress = None
        self._cmd_id = None
        self._cmd_last_updated_date = None
        self._cmd_status = None
        self._cmd_type = None
        self._enterprise_id = None
        self._enterprise_name = None
        self._entity_scope = None
        self._bootstrap_status = None
        self._product_name = None
        self._associated_entity_type = None
        self._associated_ns_gateway_id = None
        self._huge_page_setting = None
        self._external_id = None
        self._system_id = None
        
        self.expose_attribute(local_name="mac_address", remote_name="MACAddress", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="ca_certificate", remote_name="CACertificate", attribute_type=dict, is_required=False, is_unique=False)
        self.expose_attribute(local_name="aar_application_release_date", remote_name="AARApplicationReleaseDate", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="aar_application_version", remote_name="AARApplicationVersion", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="bios_release_date", remote_name="BIOSReleaseDate", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="bios_version", remote_name="BIOSVersion", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="sku", remote_name="SKU", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="tpm_status", remote_name="TPMStatus", attribute_type=int, is_required=False, is_unique=False)
        self.expose_attribute(local_name="tpm_version", remote_name="TPMVersion", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="cpu_core_allocation", remote_name="CPUCoreAllocation", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="cpu_type", remote_name="CPUType", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="nsg_version", remote_name="NSGVersion", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="uuid", remote_name="UUID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="family", remote_name="family", attribute_type=str, is_required=False, is_unique=False, choices=[u'ANY', u'NSG_AMI', u'NSG_AZ', u'NSG_C', u'NSG_DOCKER', u'NSG_E', u'NSG_E200', u'NSG_E300', u'NSG_V', u'NSG_X', u'NSG_X200'])
        self.expose_attribute(local_name="patches_detail", remote_name="patchesDetail", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="serial_number", remote_name="serialNumber", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="personality", remote_name="personality", attribute_type=str, is_required=False, is_unique=False, choices=[u'NSG', u'NSGBR', u'NSGDUC'])
        self.expose_attribute(local_name="certificate", remote_name="certificate", attribute_type=dict, is_required=False, is_unique=False)
        self.expose_attribute(local_name="libraries", remote_name="libraries", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="cmd_detailed_status", remote_name="cmdDetailedStatus", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="cmd_detailed_status_code", remote_name="cmdDetailedStatusCode", attribute_type=int, is_required=False, is_unique=False)
        self.expose_attribute(local_name="cmd_download_progress", remote_name="cmdDownloadProgress", attribute_type=dict, is_required=False, is_unique=False)
        self.expose_attribute(local_name="cmd_id", remote_name="cmdID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="cmd_last_updated_date", remote_name="cmdLastUpdatedDate", attribute_type=float, is_required=False, is_unique=False)
        self.expose_attribute(local_name="cmd_status", remote_name="cmdStatus", attribute_type=str, is_required=False, is_unique=False, choices=[u'ABANDONED', u'COMPLETED', u'FAILED', u'RUNNING', u'SKIPPED', u'STARTED', u'UNKNOWN'])
        self.expose_attribute(local_name="cmd_type", remote_name="cmdType", attribute_type=str, is_required=False, is_unique=False, choices=[u'NSG_DOWNLOAD_OS_IMAGE', u'NSG_UPGRADE_TO_IMAGE'])
        self.expose_attribute(local_name="enterprise_id", remote_name="enterpriseID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="enterprise_name", remote_name="enterpriseName", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
        self.expose_attribute(local_name="bootstrap_status", remote_name="bootstrapStatus", attribute_type=str, is_required=False, is_unique=False, choices=[u'ACTIVE', u'CERTIFICATE_SIGNED', u'INACTIVE', u'NOTIFICATION_APP_REQ_ACK', u'NOTIFICATION_APP_REQ_SENT'])
        self.expose_attribute(local_name="product_name", remote_name="productName", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="associated_entity_type", remote_name="associatedEntityType", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="associated_ns_gateway_id", remote_name="associatedNSGatewayID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="huge_page_setting", remote_name="hugePageSetting", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
        self.expose_attribute(local_name="system_id", remote_name="systemID", attribute_type=str, is_required=False, is_unique=False)
        

        self._compute_args(**kwargs)

    # Properties
    
    @property
    def mac_address(self):
        """ Get mac_address value.

            Notes:
                A comma separated list of MAC Addresses associated to the NSG's interfaces (eg, port1, port2, port3).

                
                This attribute is named `MACAddress` in VSD API.
                
        """
        return self._mac_address

    @mac_address.setter
    def mac_address(self, value):
        """ Set mac_address value.

            Notes:
                A comma separated list of MAC Addresses associated to the NSG's interfaces (eg, port1, port2, port3).

                
                This attribute is named `MACAddress` in VSD API.
                
        """
        self._mac_address = value

    
    @property
    def ca_certificate(self):
        """ Get ca_certificate value.

            Notes:
                The certficate metadata of NSG's certificate authority.

                
                This attribute is named `CACertificate` in VSD API.
                
        """
        return self._ca_certificate

    @ca_certificate.setter
    def ca_certificate(self, value):
        """ Set ca_certificate value.

            Notes:
                The certficate metadata of NSG's certificate authority.

                
                This attribute is named `CACertificate` in VSD API.
                
        """
        self._ca_certificate = value

    
    @property
    def aar_application_release_date(self):
        """ Get aar_application_release_date value.

            Notes:
                Release Date of the AAR Application

                
                This attribute is named `AARApplicationReleaseDate` in VSD API.
                
        """
        return self._aar_application_release_date

    @aar_application_release_date.setter
    def aar_application_release_date(self, value):
        """ Set aar_application_release_date value.

            Notes:
                Release Date of the AAR Application

                
                This attribute is named `AARApplicationReleaseDate` in VSD API.
                
        """
        self._aar_application_release_date = value

    
    @property
    def aar_application_version(self):
        """ Get aar_application_version value.

            Notes:
                The AAR Application Version

                
                This attribute is named `AARApplicationVersion` in VSD API.
                
        """
        return self._aar_application_version

    @aar_application_version.setter
    def aar_application_version(self, value):
        """ Set aar_application_version value.

            Notes:
                The AAR Application Version

                
                This attribute is named `AARApplicationVersion` in VSD API.
                
        """
        self._aar_application_version = value

    
    @property
    def bios_release_date(self):
        """ Get bios_release_date value.

            Notes:
                Release Date of the NSG BiOS

                
                This attribute is named `BIOSReleaseDate` in VSD API.
                
        """
        return self._bios_release_date

    @bios_release_date.setter
    def bios_release_date(self, value):
        """ Set bios_release_date value.

            Notes:
                Release Date of the NSG BiOS

                
                This attribute is named `BIOSReleaseDate` in VSD API.
                
        """
        self._bios_release_date = value

    
    @property
    def bios_version(self):
        """ Get bios_version value.

            Notes:
                NSG BIOS Version as received from the NSG during bootstrap or a reboot.  If the information exeeds 255 characters, the extra characters will be truncated.

                
                This attribute is named `BIOSVersion` in VSD API.
                
        """
        return self._bios_version

    @bios_version.setter
    def bios_version(self, value):
        """ Set bios_version value.

            Notes:
                NSG BIOS Version as received from the NSG during bootstrap or a reboot.  If the information exeeds 255 characters, the extra characters will be truncated.

                
                This attribute is named `BIOSVersion` in VSD API.
                
        """
        self._bios_version = value

    
    @property
    def sku(self):
        """ Get sku value.

            Notes:
                The part number of the NSG

                
                This attribute is named `SKU` in VSD API.
                
        """
        return self._sku

    @sku.setter
    def sku(self, value):
        """ Set sku value.

            Notes:
                The part number of the NSG

                
                This attribute is named `SKU` in VSD API.
                
        """
        self._sku = value

    
    @property
    def tpm_status(self):
        """ Get tpm_status value.

            Notes:
                TPM status code as reported by the NSG during bootstrapping. This informate indicates if TPM is being used in securing the private key/certificate of an NSG. Possible values are 0(Unknown), 1(Enabled_Not_Operational), 2(Enabled_Operational), 3(Disabled).

                
                This attribute is named `TPMStatus` in VSD API.
                
        """
        return self._tpm_status

    @tpm_status.setter
    def tpm_status(self, value):
        """ Set tpm_status value.

            Notes:
                TPM status code as reported by the NSG during bootstrapping. This informate indicates if TPM is being used in securing the private key/certificate of an NSG. Possible values are 0(Unknown), 1(Enabled_Not_Operational), 2(Enabled_Operational), 3(Disabled).

                
                This attribute is named `TPMStatus` in VSD API.
                
        """
        self._tpm_status = value

    
    @property
    def tpm_version(self):
        """ Get tpm_version value.

            Notes:
                TPM (Trusted Platform Module) version as reported by the NSG.

                
                This attribute is named `TPMVersion` in VSD API.
                
        """
        return self._tpm_version

    @tpm_version.setter
    def tpm_version(self, value):
        """ Set tpm_version value.

            Notes:
                TPM (Trusted Platform Module) version as reported by the NSG.

                
                This attribute is named `TPMVersion` in VSD API.
                
        """
        self._tpm_version = value

    
    @property
    def cpu_core_allocation(self):
        """ Get cpu_core_allocation value.

            Notes:
                Current CPU allocation for network accelerated gateways.  Displays total number of cores and those isolated.

                
                This attribute is named `CPUCoreAllocation` in VSD API.
                
        """
        return self._cpu_core_allocation

    @cpu_core_allocation.setter
    def cpu_core_allocation(self, value):
        """ Set cpu_core_allocation value.

            Notes:
                Current CPU allocation for network accelerated gateways.  Displays total number of cores and those isolated.

                
                This attribute is named `CPUCoreAllocation` in VSD API.
                
        """
        self._cpu_core_allocation = value

    
    @property
    def cpu_type(self):
        """ Get cpu_type value.

            Notes:
                The NSG Processor Type based on information extracted during bootstrapping.  This may refer to a type of processor manufactured by Intel, ARM, AMD, Cyrix, VIA, or others.

                
                This attribute is named `CPUType` in VSD API.
                
        """
        return self._cpu_type

    @cpu_type.setter
    def cpu_type(self, value):
        """ Set cpu_type value.

            Notes:
                The NSG Processor Type based on information extracted during bootstrapping.  This may refer to a type of processor manufactured by Intel, ARM, AMD, Cyrix, VIA, or others.

                
                This attribute is named `CPUType` in VSD API.
                
        """
        self._cpu_type = value

    
    @property
    def nsg_version(self):
        """ Get nsg_version value.

            Notes:
                The NSG Version as reported during a bootstrap or a reboot of the NSG. 

                
                This attribute is named `NSGVersion` in VSD API.
                
        """
        return self._nsg_version

    @nsg_version.setter
    def nsg_version(self, value):
        """ Set nsg_version value.

            Notes:
                The NSG Version as reported during a bootstrap or a reboot of the NSG. 

                
                This attribute is named `NSGVersion` in VSD API.
                
        """
        self._nsg_version = value

    
    @property
    def uuid(self):
        """ Get uuid value.

            Notes:
                The Redhat/CentOS UUID of the NSG

                
                This attribute is named `UUID` in VSD API.
                
        """
        return self._uuid

    @uuid.setter
    def uuid(self, value):
        """ Set uuid value.

            Notes:
                The Redhat/CentOS UUID of the NSG

                
                This attribute is named `UUID` in VSD API.
                
        """
        self._uuid = value

    
    @property
    def name(self):
        """ Get name value.

            Notes:
                Name of the Gateway.

                
        """
        return self._name

    @name.setter
    def name(self, value):
        """ Set name value.

            Notes:
                Name of the Gateway.

                
        """
        self._name = value

    
    @property
    def family(self):
        """ Get family value.

            Notes:
                The NSG Family type as it was returned by the NSG during bootstrapping.

                
        """
        return self._family

    @family.setter
    def family(self, value):
        """ Set family value.

            Notes:
                The NSG Family type as it was returned by the NSG during bootstrapping.

                
        """
        self._family = value

    
    @property
    def patches_detail(self):
        """ Get patches_detail value.

            Notes:
                Base64 Encoded JSON String of the extra details pertaining to each successfully installed patch

                
                This attribute is named `patchesDetail` in VSD API.
                
        """
        return self._patches_detail

    @patches_detail.setter
    def patches_detail(self, value):
        """ Set patches_detail value.

            Notes:
                Base64 Encoded JSON String of the extra details pertaining to each successfully installed patch

                
                This attribute is named `patchesDetail` in VSD API.
                
        """
        self._patches_detail = value

    
    @property
    def serial_number(self):
        """ Get serial_number value.

            Notes:
                The NSG's serial number as it is stored in the system's CMOS (Motherboard)

                
                This attribute is named `serialNumber` in VSD API.
                
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, value):
        """ Set serial_number value.

            Notes:
                The NSG's serial number as it is stored in the system's CMOS (Motherboard)

                
                This attribute is named `serialNumber` in VSD API.
                
        """
        self._serial_number = value

    
    @property
    def personality(self):
        """ Get personality value.

            Notes:
                Personality of the Gateway.

                
        """
        return self._personality

    @personality.setter
    def personality(self, value):
        """ Set personality value.

            Notes:
                Personality of the Gateway.

                
        """
        self._personality = value

    
    @property
    def certificate(self):
        """ Get certificate value.

            Notes:
                The certificate metadata of NSG's current certficate.

                
        """
        return self._certificate

    @certificate.setter
    def certificate(self, value):
        """ Set certificate value.

            Notes:
                The certificate metadata of NSG's current certficate.

                
        """
        self._certificate = value

    
    @property
    def libraries(self):
        """ Get libraries value.

            Notes:
                Tracks RPM package installed for some libraries installed on the NSG.

                
        """
        return self._libraries

    @libraries.setter
    def libraries(self, value):
        """ Set libraries value.

            Notes:
                Tracks RPM package installed for some libraries installed on the NSG.

                
        """
        self._libraries = value

    
    @property
    def cmd_detailed_status(self):
        """ Get cmd_detailed_status value.

            Notes:
                Detailed status of the current running or last run command.

                
                This attribute is named `cmdDetailedStatus` in VSD API.
                
        """
        return self._cmd_detailed_status

    @cmd_detailed_status.setter
    def cmd_detailed_status(self, value):
        """ Set cmd_detailed_status value.

            Notes:
                Detailed status of the current running or last run command.

                
                This attribute is named `cmdDetailedStatus` in VSD API.
                
        """
        self._cmd_detailed_status = value

    
    @property
    def cmd_detailed_status_code(self):
        """ Get cmd_detailed_status_code value.

            Notes:
                Numerical value representing the code mapping to detailed status of the current or last command operation.

                
                This attribute is named `cmdDetailedStatusCode` in VSD API.
                
        """
        return self._cmd_detailed_status_code

    @cmd_detailed_status_code.setter
    def cmd_detailed_status_code(self, value):
        """ Set cmd_detailed_status_code value.

            Notes:
                Numerical value representing the code mapping to detailed status of the current or last command operation.

                
                This attribute is named `cmdDetailedStatusCode` in VSD API.
                
        """
        self._cmd_detailed_status_code = value

    
    @property
    def cmd_download_progress(self):
        """ Get cmd_download_progress value.

            Notes:
                DownloadProgress object representing the progress of Gateway image download.

                
                This attribute is named `cmdDownloadProgress` in VSD API.
                
        """
        return self._cmd_download_progress

    @cmd_download_progress.setter
    def cmd_download_progress(self, value):
        """ Set cmd_download_progress value.

            Notes:
                DownloadProgress object representing the progress of Gateway image download.

                
                This attribute is named `cmdDownloadProgress` in VSD API.
                
        """
        self._cmd_download_progress = value

    
    @property
    def cmd_id(self):
        """ Get cmd_id value.

            Notes:
                Identifier of the running or last Command.

                
                This attribute is named `cmdID` in VSD API.
                
        """
        return self._cmd_id

    @cmd_id.setter
    def cmd_id(self, value):
        """ Set cmd_id value.

            Notes:
                Identifier of the running or last Command.

                
                This attribute is named `cmdID` in VSD API.
                
        """
        self._cmd_id = value

    
    @property
    def cmd_last_updated_date(self):
        """ Get cmd_last_updated_date value.

            Notes:
                Time stamp when the command was last updated.

                
                This attribute is named `cmdLastUpdatedDate` in VSD API.
                
        """
        return self._cmd_last_updated_date

    @cmd_last_updated_date.setter
    def cmd_last_updated_date(self, value):
        """ Set cmd_last_updated_date value.

            Notes:
                Time stamp when the command was last updated.

                
                This attribute is named `cmdLastUpdatedDate` in VSD API.
                
        """
        self._cmd_last_updated_date = value

    
    @property
    def cmd_status(self):
        """ Get cmd_status value.

            Notes:
                Status of the current or last command.

                
                This attribute is named `cmdStatus` in VSD API.
                
        """
        return self._cmd_status

    @cmd_status.setter
    def cmd_status(self, value):
        """ Set cmd_status value.

            Notes:
                Status of the current or last command.

                
                This attribute is named `cmdStatus` in VSD API.
                
        """
        self._cmd_status = value

    
    @property
    def cmd_type(self):
        """ Get cmd_type value.

            Notes:
                Specifies the type of command that is stated for execution on the system. A request for download or a request for upgrade.

                
                This attribute is named `cmdType` in VSD API.
                
        """
        return self._cmd_type

    @cmd_type.setter
    def cmd_type(self, value):
        """ Set cmd_type value.

            Notes:
                Specifies the type of command that is stated for execution on the system. A request for download or a request for upgrade.

                
                This attribute is named `cmdType` in VSD API.
                
        """
        self._cmd_type = value

    
    @property
    def enterprise_id(self):
        """ Get enterprise_id value.

            Notes:
                The enterprise associated with this Gateway.

                
                This attribute is named `enterpriseID` in VSD API.
                
        """
        return self._enterprise_id

    @enterprise_id.setter
    def enterprise_id(self, value):
        """ Set enterprise_id value.

            Notes:
                The enterprise associated with this Gateway.

                
                This attribute is named `enterpriseID` in VSD API.
                
        """
        self._enterprise_id = value

    
    @property
    def enterprise_name(self):
        """ Get enterprise_name value.

            Notes:
                Name of the Enterprise associated with this Gateway.

                
                This attribute is named `enterpriseName` in VSD API.
                
        """
        return self._enterprise_name

    @enterprise_name.setter
    def enterprise_name(self, value):
        """ Set enterprise_name value.

            Notes:
                Name of the Enterprise associated with this Gateway.

                
                This attribute is named `enterpriseName` in VSD API.
                
        """
        self._enterprise_name = value

    
    @property
    def entity_scope(self):
        """ Get entity_scope value.

            Notes:
                Specify if scope of entity is Data center or Enterprise level

                
                This attribute is named `entityScope` in VSD API.
                
        """
        return self._entity_scope

    @entity_scope.setter
    def entity_scope(self, value):
        """ Set entity_scope value.

            Notes:
                Specify if scope of entity is Data center or Enterprise level

                
                This attribute is named `entityScope` in VSD API.
                
        """
        self._entity_scope = value

    
    @property
    def bootstrap_status(self):
        """ Get bootstrap_status value.

            Notes:
                The bootstrap status of the NSG from which the infomation was collected.

                
                This attribute is named `bootstrapStatus` in VSD API.
                
        """
        return self._bootstrap_status

    @bootstrap_status.setter
    def bootstrap_status(self, value):
        """ Set bootstrap_status value.

            Notes:
                The bootstrap status of the NSG from which the infomation was collected.

                
                This attribute is named `bootstrapStatus` in VSD API.
                
        """
        self._bootstrap_status = value

    
    @property
    def product_name(self):
        """ Get product_name value.

            Notes:
                NSG Product Name as reported when the device bootstraps.

                
                This attribute is named `productName` in VSD API.
                
        """
        return self._product_name

    @product_name.setter
    def product_name(self, value):
        """ Set product_name value.

            Notes:
                NSG Product Name as reported when the device bootstraps.

                
                This attribute is named `productName` in VSD API.
                
        """
        self._product_name = value

    
    @property
    def associated_entity_type(self):
        """ Get associated_entity_type value.

            Notes:
                Object type of the associated entity.

                
                This attribute is named `associatedEntityType` in VSD API.
                
        """
        return self._associated_entity_type

    @associated_entity_type.setter
    def associated_entity_type(self, value):
        """ Set associated_entity_type value.

            Notes:
                Object type of the associated entity.

                
                This attribute is named `associatedEntityType` in VSD API.
                
        """
        self._associated_entity_type = value

    
    @property
    def associated_ns_gateway_id(self):
        """ Get associated_ns_gateway_id value.

            Notes:
                The ID of the NSG from which the infomation was collected.

                
                This attribute is named `associatedNSGatewayID` in VSD API.
                
        """
        return self._associated_ns_gateway_id

    @associated_ns_gateway_id.setter
    def associated_ns_gateway_id(self, value):
        """ Set associated_ns_gateway_id value.

            Notes:
                The ID of the NSG from which the infomation was collected.

                
                This attribute is named `associatedNSGatewayID` in VSD API.
                
        """
        self._associated_ns_gateway_id = value

    
    @property
    def huge_page_setting(self):
        """ Get huge_page_setting value.

            Notes:
                The size and number of huge pages for an NSG that is running in network accelerated mode.  Hugepage values states the portion of memory reserved for network accelerated services.

                
                This attribute is named `hugePageSetting` in VSD API.
                
        """
        return self._huge_page_setting

    @huge_page_setting.setter
    def huge_page_setting(self, value):
        """ Set huge_page_setting value.

            Notes:
                The size and number of huge pages for an NSG that is running in network accelerated mode.  Hugepage values states the portion of memory reserved for network accelerated services.

                
                This attribute is named `hugePageSetting` in VSD API.
                
        """
        self._huge_page_setting = value

    
    @property
    def external_id(self):
        """ Get external_id value.

            Notes:
                External object ID. Used for integration with third party systems

                
                This attribute is named `externalID` in VSD API.
                
        """
        return self._external_id

    @external_id.setter
    def external_id(self, value):
        """ Set external_id value.

            Notes:
                External object ID. Used for integration with third party systems

                
                This attribute is named `externalID` in VSD API.
                
        """
        self._external_id = value

    
    @property
    def system_id(self):
        """ Get system_id value.

            Notes:
                System identifier of the Gateway.

                
                This attribute is named `systemID` in VSD API.
                
        """
        return self._system_id

    @system_id.setter
    def system_id(self, value):
        """ Set system_id value.

            Notes:
                System identifier of the Gateway.

                
                This attribute is named `systemID` in VSD API.
                
        """
        self._system_id = value

    

    


# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


__all__ = ['NUVSDSession', 'NUAddressMap', 'NUAddressRange', 'NUAggregatedDomain', 'NUAggregateMetadata', 'NUAlarm', 'NUAllAlarm', 'NUAllGateway', 'NUAllocationPool', 'NUAllRedundancyGroup', 'NUApplication', 'NUApplicationBinding', 'NUApplicationperformancemanagement', 'NUApplicationperformancemanagementbinding', 'NUAutoDiscoverCluster', 'NUAutodiscovereddatacenter', 'NUAutoDiscoveredGateway', 'NUAutoDiscoverHypervisorFromCluster', 'NUAvatar', 'NUAzureCloud', 'NUBandwidthTestResult', 'NUBFDSession', 'NUBGPNeighbor', 'NUBGPPeer', 'NUBGPProfile', 'NUBootstrap', 'NUBootstrapActivation', 'NUBRConnection', 'NUBridgeInterface', 'NUBulkStatistics', 'NUCaptivePortalProfile', 'NUCertificate', 'NUCertificateMetadata', 'NUCloudMgmtSystem', 'NUCommand', 'NUConnectionendpoint', 'NUContainer', 'NUContainerInterface', 'NUContainerResync', 'NUControllerVRSLink', 'NUCOSRemarkingPolicy', 'NUCOSRemarkingPolicyTable', 'NUCSNATPool', 'NUCTranslationMap', 'NUCustomProperty', 'NUDefaultGateway', 'NUDemarcationService', 'NUDeploymentFailure', 'NUDestinationurl', 'NUDHCPOption', 'NUDHCPv6Option', 'NUDiskStat', 'NUDomain', 'NUDomainFIPAclTemplate', 'NUDomainFIPAclTemplateEntry', 'NUDomainKindSummary', 'NUDomainTemplate', 'NUDownloadProgress', 'NUDSCPForwardingClassMapping', 'NUDSCPForwardingClassTable', 'NUDSCPRemarkingPolicy', 'NUDSCPRemarkingPolicyTable', 'NUDUCGroup', 'NUDUCGroupBinding', 'NUEgressACLEntryTemplate', 'NUEgressACLTemplate', 'NUEgressAdvFwdEntryTemplate', 'NUEgressAdvFwdTemplate', 'NUEgressAuditACLEntryTemplate', 'NUEgressAuditACLTemplate', 'NUEgressProfile', 'NUEgressQOSPolicy', 'NUEnterprise', 'NUEnterpriseNetwork', 'NUEnterprisePermission', 'NUEnterpriseProfile', 'NUEnterpriseSecuredData', 'NUEnterpriseSecurity', 'NUEsIlmPolicy', 'NUEsIndexConfig', 'NUEthernetSegmentGroup', 'NUEthernetSegmentGWGroup', 'NUEventLog', 'NUFirewallAcl', 'NUFirewallRule', 'NUFloatingIp', 'NUForwardingClass', 'NUForwardingPathList', 'NUForwardingPathListEntry', 'NUGateway', 'NUGatewayRedundantPort', 'NUGatewaySecuredData', 'NUGatewaySecurity', 'NUGatewaysLocation', 'NUGatewayTemplate', 'NUGlobalMetadata', 'NUGNMIProfile', 'NUGNMISession', 'NUGroup', 'NUGroupKeyEncryptionProfile', 'NUHostInterface', 'NUHSC', 'NUIDPProfile', 'NUIDPProfileAction', 'NUIDPSignature', 'NUIKECertificate', 'NUIKEEncryptionprofile', 'NUIKEGateway', 'NUIKEGatewayConfig', 'NUIKEGatewayConnection', 'NUIKEGatewayProfile', 'NUIKEPSK', 'NUIKESubnet', 'NUInfrastructureAccessProfile', 'NUInfrastructureConfig', 'NUInfrastructureEVDFProfile', 'NUInfrastructureGatewayProfile', 'NUInfrastructureVscProfile', 'NUIngressACLEntryTemplate', 'NUIngressACLTemplate', 'NUIngressAdvFwdEntryTemplate', 'NUIngressAdvFwdTemplate', 'NUIngressAuditACLEntryTemplate', 'NUIngressAuditACLTemplate', 'NUIngressProfile', 'NUIngressQOSPolicy', 'NUIPFilterProfile', 'NUIPReservation', 'NUIPv6FilterProfile', 'NUJob', 'NUKeyServerMember', 'NUKeyServerMonitor', 'NUKeyServerMonitorEncryptedSeed', 'NUKeyServerMonitorSeed', 'NUKeyServerMonitorSEK', 'NUL2Domain', 'NUL2DomainTemplate', 'NUL4Service', 'NUL4ServiceGroup', 'NUL7applicationsignature', 'NULDAPConfiguration', 'NULicense', 'NULicenseStatus', 'NULink', 'NULocation', 'NULTEInformation', 'NULtestatistics', 'NUMACFilterProfile', 'NUMe', 'NUMetadata', 'NUMirrorDestination', 'NUMirrorDestinationGroup', 'NUMonitoringPort', 'NUMonitorscope', 'NUMTUDiscoveryTestResult', 'NUMultiCastChannelMap', 'NUMultiCastList', 'NUMultiCastRange', 'NUMultiNICVPort', 'NUNATMapEntry', 'NUNetconfGateway', 'NUNetconfManager', 'NUNetconfProfile', 'NUNetconfSession', 'NUNetworkLayout', 'NUNetworkMacroGroup', 'NUNetworkPerformanceBinding', 'NUNetworkPerformanceMeasurement', 'NUNextHop', 'NUNSGateway', 'NUNSGatewayMonitor', 'NUNSGatewaysCount', 'NUNSGatewaySummary', 'NUNSGatewayTemplate', 'NUNSGGroup', 'NUNSGInfo', 'NUNSGPatchProfile', 'NUNSGRoutingPolicyBinding', 'NUNSGUpgradeProfile', 'NUNSPort', 'NUNSPortInfo', 'NUNSPortTemplate', 'NUNSRedundantGatewayGroup', 'NUOSPFArea', 'NUOSPFInstance', 'NUOSPFInterface', 'NUOverlayAddressPool', 'NUOverlayManagementProfile', 'NUOverlayManagementSubnetProfile', 'NUOverlayMirrorDestination', 'NUOverlayMirrorDestinationTemplate', 'NUOverlayPATNATEntry', 'NUPatch', 'NUPATIPEntry', 'NUPATMapper', 'NUPATNATPool', 'NUPerformanceMonitor', 'NUPermission', 'NUPGExpression', 'NUPGExpressionTemplate', 'NUPolicyDecision', 'NUPolicyEntry', 'NUPolicyGroup', 'NUPolicyGroupCategory', 'NUPolicyGroupTemplate', 'NUPolicyObjectGroup', 'NUPolicyStatement', 'NUPort', 'NUPortMapping', 'NUPortTemplate', 'NUProxyARPFilter', 'NUPSNATPool', 'NUPSPATMap', 'NUPTranslationMap', 'NUPublicNetworkMacro', 'NUQOS', 'NUQosPolicer', 'NURateLimiter', 'NURedirectionTarget', 'NURedirectionTargetTemplate', 'NURedundancyGroup', 'NURedundantPort', 'NURemoteVrsInfo', 'NURole', 'NURoleentry', 'NURoutingPolicy', 'NURoutingPolicyBinding', 'NUSaaSApplicationGroup', 'NUSaaSApplicationType', 'NUSAPEgressQoSProfile', 'NUSAPIngressQoSProfile', 'NUSharedNetworkResource', 'NUShuntLink', 'NUSiteInfo', 'NUSPATSourcesPool', 'NUSSHKey', 'NUSSIDConnection', 'NUStaticRoute', 'NUStatistics', 'NUStatisticsPolicy', 'NUStatsCollectorInfo', 'NUSubnet', 'NUSubnetTemplate', 'NUSupplementalInfraConfig', 'NUSyslogDestination', 'NUSysmonUplinkConnection', 'NUSystemConfig', 'NUTCA', 'NUTCPConnectTestResult', 'NUTest', 'NUTestDefinition', 'NUTestRun', 'NUTestSuite', 'NUTestSuiteRun', 'NUThreatPreventionInfo', 'NUThreatPreventionNodeInfo', 'NUThreatPreventionServerConnection', 'NUTier', 'NUTrunk', 'NUUDPProbeTestResult', 'NUUnderlay', 'NUUnderlayTest', 'NUUplinkConnection', 'NUUplinkRD', 'NUUser', 'NUUserContext', 'NUVCenter', 'NUVCenterCluster', 'NUVCenterDataCenter', 'NUVCenterEAMConfig', 'NUVCenterHypervisor', 'NUVCenterVRSConfig', 'NUVirtualFirewallPolicy', 'NUVirtualFirewallRule', 'NUVirtualIP', 'NUVirtualUplink', 'NUVLAN', 'NUVLANTemplate', 'NUVM', 'NUVMInterface', 'NUVMIPReservation', 'NUVMResync', 'NUVNF', 'NUVNFCatalog', 'NUVNFDescriptor', 'NUVNFDomainMapping', 'NUVNFInterface', 'NUVNFInterfaceDescriptor', 'NUVNFMetadata', 'NUVNFThresholdPolicy', 'NUVPNConnection', 'NUVPort', 'NUVPortInfo', 'NUVPortMirror', 'NUVRS', 'NUVRSAddressRange', 'NUvrsInfo', 'NUVRSMetrics', 'NUVRSRedeploymentpolicy', 'NUVSC', 'NUVSD', 'NUVSDComponent', 'NUVSDConfig', 'NUVsgRedundantPort', 'NUVSP', 'NUWANService', 'NUWebCategory', 'NUWebDomainName', 'NUWirelessPort', 'NUZFBAutoAssignment', 'NUZFBRequest', 'NUZone', 'NUZoneTemplate']

from .nuaddressmap import NUAddressMap
from .nuaddressrange import NUAddressRange
from .nuaggregateddomain import NUAggregatedDomain
from .nuaggregatemetadata import NUAggregateMetadata
from .nualarm import NUAlarm
from .nuallalarm import NUAllAlarm
from .nuallgateway import NUAllGateway
from .nuallocationpool import NUAllocationPool
from .nuallredundancygroup import NUAllRedundancyGroup
from .nuapplication import NUApplication
from .nuapplicationbinding import NUApplicationBinding
from .nuapplicationperformancemanagement import NUApplicationperformancemanagement
from .nuapplicationperformancemanagementbinding import NUApplicationperformancemanagementbinding
from .nuautodiscovercluster import NUAutoDiscoverCluster
from .nuautodiscovereddatacenter import NUAutodiscovereddatacenter
from .nuautodiscoveredgateway import NUAutoDiscoveredGateway
from .nuautodiscoverhypervisorfromcluster import NUAutoDiscoverHypervisorFromCluster
from .nuavatar import NUAvatar
from .nuazurecloud import NUAzureCloud
from .nubandwidthtestresult import NUBandwidthTestResult
from .nubfdsession import NUBFDSession
from .nubgpneighbor import NUBGPNeighbor
from .nubgppeer import NUBGPPeer
from .nubgpprofile import NUBGPProfile
from .nubootstrap import NUBootstrap
from .nubootstrapactivation import NUBootstrapActivation
from .nubrconnection import NUBRConnection
from .nubridgeinterface import NUBridgeInterface
from .nubulkstatistics import NUBulkStatistics
from .nucaptiveportalprofile import NUCaptivePortalProfile
from .nucertificate import NUCertificate
from .nucertificatemetadata import NUCertificateMetadata
from .nucloudmgmtsystem import NUCloudMgmtSystem
from .nucommand import NUCommand
from .nuconnectionendpoint import NUConnectionendpoint
from .nucontainer import NUContainer
from .nucontainerinterface import NUContainerInterface
from .nucontainerresync import NUContainerResync
from .nucontrollervrslink import NUControllerVRSLink
from .nucosremarkingpolicy import NUCOSRemarkingPolicy
from .nucosremarkingpolicytable import NUCOSRemarkingPolicyTable
from .nucsnatpool import NUCSNATPool
from .nuctranslationmap import NUCTranslationMap
from .nucustomproperty import NUCustomProperty
from .nudefaultgateway import NUDefaultGateway
from .nudemarcationservice import NUDemarcationService
from .nudeploymentfailure import NUDeploymentFailure
from .nudestinationurl import NUDestinationurl
from .nudhcpoption import NUDHCPOption
from .nudhcpv6option import NUDHCPv6Option
from .nudiskstat import NUDiskStat
from .nudomain import NUDomain
from .nudomainfipacltemplate import NUDomainFIPAclTemplate
from .nudomainfipacltemplateentry import NUDomainFIPAclTemplateEntry
from .nudomainkindsummary import NUDomainKindSummary
from .nudomaintemplate import NUDomainTemplate
from .nudownloadprogress import NUDownloadProgress
from .nudscpforwardingclassmapping import NUDSCPForwardingClassMapping
from .nudscpforwardingclasstable import NUDSCPForwardingClassTable
from .nudscpremarkingpolicy import NUDSCPRemarkingPolicy
from .nudscpremarkingpolicytable import NUDSCPRemarkingPolicyTable
from .nuducgroup import NUDUCGroup
from .nuducgroupbinding import NUDUCGroupBinding
from .nuegressaclentrytemplate import NUEgressACLEntryTemplate
from .nuegressacltemplate import NUEgressACLTemplate
from .nuegressadvfwdentrytemplate import NUEgressAdvFwdEntryTemplate
from .nuegressadvfwdtemplate import NUEgressAdvFwdTemplate
from .nuegressauditaclentrytemplate import NUEgressAuditACLEntryTemplate
from .nuegressauditacltemplate import NUEgressAuditACLTemplate
from .nuegressprofile import NUEgressProfile
from .nuegressqospolicy import NUEgressQOSPolicy
from .nuenterprise import NUEnterprise
from .nuenterprisenetwork import NUEnterpriseNetwork
from .nuenterprisepermission import NUEnterprisePermission
from .nuenterpriseprofile import NUEnterpriseProfile
from .nuenterprisesecureddata import NUEnterpriseSecuredData
from .nuenterprisesecurity import NUEnterpriseSecurity
from .nuesilmpolicy import NUEsIlmPolicy
from .nuesindexconfig import NUEsIndexConfig
from .nuethernetsegmentgroup import NUEthernetSegmentGroup
from .nuethernetsegmentgwgroup import NUEthernetSegmentGWGroup
from .nueventlog import NUEventLog
from .nufirewallacl import NUFirewallAcl
from .nufirewallrule import NUFirewallRule
from .nufloatingip import NUFloatingIp
from .nuforwardingclass import NUForwardingClass
from .nuforwardingpathlist import NUForwardingPathList
from .nuforwardingpathlistentry import NUForwardingPathListEntry
from .nugateway import NUGateway
from .nugatewayredundantport import NUGatewayRedundantPort
from .nugatewaysecureddata import NUGatewaySecuredData
from .nugatewaysecurity import NUGatewaySecurity
from .nugatewayslocation import NUGatewaysLocation
from .nugatewaytemplate import NUGatewayTemplate
from .nuglobalmetadata import NUGlobalMetadata
from .nugnmiprofile import NUGNMIProfile
from .nugnmisession import NUGNMISession
from .nugroup import NUGroup
from .nugroupkeyencryptionprofile import NUGroupKeyEncryptionProfile
from .nuhostinterface import NUHostInterface
from .nuhsc import NUHSC
from .nuidpprofile import NUIDPProfile
from .nuidpprofileaction import NUIDPProfileAction
from .nuidpsignature import NUIDPSignature
from .nuikecertificate import NUIKECertificate
from .nuikeencryptionprofile import NUIKEEncryptionprofile
from .nuikegateway import NUIKEGateway
from .nuikegatewayconfig import NUIKEGatewayConfig
from .nuikegatewayconnection import NUIKEGatewayConnection
from .nuikegatewayprofile import NUIKEGatewayProfile
from .nuikepsk import NUIKEPSK
from .nuikesubnet import NUIKESubnet
from .nuinfrastructureaccessprofile import NUInfrastructureAccessProfile
from .nuinfrastructureconfig import NUInfrastructureConfig
from .nuinfrastructureevdfprofile import NUInfrastructureEVDFProfile
from .nuinfrastructuregatewayprofile import NUInfrastructureGatewayProfile
from .nuinfrastructurevscprofile import NUInfrastructureVscProfile
from .nuingressaclentrytemplate import NUIngressACLEntryTemplate
from .nuingressacltemplate import NUIngressACLTemplate
from .nuingressadvfwdentrytemplate import NUIngressAdvFwdEntryTemplate
from .nuingressadvfwdtemplate import NUIngressAdvFwdTemplate
from .nuingressauditaclentrytemplate import NUIngressAuditACLEntryTemplate
from .nuingressauditacltemplate import NUIngressAuditACLTemplate
from .nuingressprofile import NUIngressProfile
from .nuingressqospolicy import NUIngressQOSPolicy
from .nuipfilterprofile import NUIPFilterProfile
from .nuipreservation import NUIPReservation
from .nuipv6filterprofile import NUIPv6FilterProfile
from .nujob import NUJob
from .nukeyservermember import NUKeyServerMember
from .nukeyservermonitor import NUKeyServerMonitor
from .nukeyservermonitorencryptedseed import NUKeyServerMonitorEncryptedSeed
from .nukeyservermonitorseed import NUKeyServerMonitorSeed
from .nukeyservermonitorsek import NUKeyServerMonitorSEK
from .nul2domain import NUL2Domain
from .nul2domaintemplate import NUL2DomainTemplate
from .nul4service import NUL4Service
from .nul4servicegroup import NUL4ServiceGroup
from .nul7applicationsignature import NUL7applicationsignature
from .nuldapconfiguration import NULDAPConfiguration
from .nulicense import NULicense
from .nulicensestatus import NULicenseStatus
from .nulink import NULink
from .nulocation import NULocation
from .nulteinformation import NULTEInformation
from .nultestatistics import NULtestatistics
from .numacfilterprofile import NUMACFilterProfile
from .nume import NUMe
from .numetadata import NUMetadata
from .numirrordestination import NUMirrorDestination
from .numirrordestinationgroup import NUMirrorDestinationGroup
from .numonitoringport import NUMonitoringPort
from .numonitorscope import NUMonitorscope
from .numtudiscoverytestresult import NUMTUDiscoveryTestResult
from .numulticastchannelmap import NUMultiCastChannelMap
from .numulticastlist import NUMultiCastList
from .numulticastrange import NUMultiCastRange
from .numultinicvport import NUMultiNICVPort
from .nunatmapentry import NUNATMapEntry
from .nunetconfgateway import NUNetconfGateway
from .nunetconfmanager import NUNetconfManager
from .nunetconfprofile import NUNetconfProfile
from .nunetconfsession import NUNetconfSession
from .nunetworklayout import NUNetworkLayout
from .nunetworkmacrogroup import NUNetworkMacroGroup
from .nunetworkperformancebinding import NUNetworkPerformanceBinding
from .nunetworkperformancemeasurement import NUNetworkPerformanceMeasurement
from .nunexthop import NUNextHop
from .nunsgateway import NUNSGateway
from .nunsgatewaymonitor import NUNSGatewayMonitor
from .nunsgatewayscount import NUNSGatewaysCount
from .nunsgatewaysummary import NUNSGatewaySummary
from .nunsgatewaytemplate import NUNSGatewayTemplate
from .nunsggroup import NUNSGGroup
from .nunsginfo import NUNSGInfo
from .nunsgpatchprofile import NUNSGPatchProfile
from .nunsgroutingpolicybinding import NUNSGRoutingPolicyBinding
from .nunsgupgradeprofile import NUNSGUpgradeProfile
from .nunsport import NUNSPort
from .nunsportinfo import NUNSPortInfo
from .nunsporttemplate import NUNSPortTemplate
from .nunsredundantgatewaygroup import NUNSRedundantGatewayGroup
from .nuospfarea import NUOSPFArea
from .nuospfinstance import NUOSPFInstance
from .nuospfinterface import NUOSPFInterface
from .nuoverlayaddresspool import NUOverlayAddressPool
from .nuoverlaymanagementprofile import NUOverlayManagementProfile
from .nuoverlaymanagementsubnetprofile import NUOverlayManagementSubnetProfile
from .nuoverlaymirrordestination import NUOverlayMirrorDestination
from .nuoverlaymirrordestinationtemplate import NUOverlayMirrorDestinationTemplate
from .nuoverlaypatnatentry import NUOverlayPATNATEntry
from .nupatch import NUPatch
from .nupatipentry import NUPATIPEntry
from .nupatmapper import NUPATMapper
from .nupatnatpool import NUPATNATPool
from .nuperformancemonitor import NUPerformanceMonitor
from .nupermission import NUPermission
from .nupgexpression import NUPGExpression
from .nupgexpressiontemplate import NUPGExpressionTemplate
from .nupolicydecision import NUPolicyDecision
from .nupolicyentry import NUPolicyEntry
from .nupolicygroup import NUPolicyGroup
from .nupolicygroupcategory import NUPolicyGroupCategory
from .nupolicygrouptemplate import NUPolicyGroupTemplate
from .nupolicyobjectgroup import NUPolicyObjectGroup
from .nupolicystatement import NUPolicyStatement
from .nuport import NUPort
from .nuportmapping import NUPortMapping
from .nuporttemplate import NUPortTemplate
from .nuproxyarpfilter import NUProxyARPFilter
from .nupsnatpool import NUPSNATPool
from .nupspatmap import NUPSPATMap
from .nuptranslationmap import NUPTranslationMap
from .nupublicnetworkmacro import NUPublicNetworkMacro
from .nuqos import NUQOS
from .nuqospolicer import NUQosPolicer
from .nuratelimiter import NURateLimiter
from .nuredirectiontarget import NURedirectionTarget
from .nuredirectiontargettemplate import NURedirectionTargetTemplate
from .nuredundancygroup import NURedundancyGroup
from .nuredundantport import NURedundantPort
from .nuremotevrsinfo import NURemoteVrsInfo
from .nurole import NURole
from .nuroleentry import NURoleentry
from .nuroutingpolicy import NURoutingPolicy
from .nuroutingpolicybinding import NURoutingPolicyBinding
from .nusaasapplicationgroup import NUSaaSApplicationGroup
from .nusaasapplicationtype import NUSaaSApplicationType
from .nusapegressqosprofile import NUSAPEgressQoSProfile
from .nusapingressqosprofile import NUSAPIngressQoSProfile
from .nusharednetworkresource import NUSharedNetworkResource
from .nushuntlink import NUShuntLink
from .nusiteinfo import NUSiteInfo
from .nuspatsourcespool import NUSPATSourcesPool
from .nusshkey import NUSSHKey
from .nussidconnection import NUSSIDConnection
from .nustaticroute import NUStaticRoute
from .nustatistics import NUStatistics
from .nustatisticspolicy import NUStatisticsPolicy
from .nustatscollectorinfo import NUStatsCollectorInfo
from .nusubnet import NUSubnet
from .nusubnettemplate import NUSubnetTemplate
from .nusupplementalinfraconfig import NUSupplementalInfraConfig
from .nusyslogdestination import NUSyslogDestination
from .nusysmonuplinkconnection import NUSysmonUplinkConnection
from .nusystemconfig import NUSystemConfig
from .nutca import NUTCA
from .nutcpconnecttestresult import NUTCPConnectTestResult
from .nutest import NUTest
from .nutestdefinition import NUTestDefinition
from .nutestrun import NUTestRun
from .nutestsuite import NUTestSuite
from .nutestsuiterun import NUTestSuiteRun
from .nuthreatpreventioninfo import NUThreatPreventionInfo
from .nuthreatpreventionnodeinfo import NUThreatPreventionNodeInfo
from .nuthreatpreventionserverconnection import NUThreatPreventionServerConnection
from .nutier import NUTier
from .nutrunk import NUTrunk
from .nuudpprobetestresult import NUUDPProbeTestResult
from .nuunderlay import NUUnderlay
from .nuunderlaytest import NUUnderlayTest
from .nuuplinkconnection import NUUplinkConnection
from .nuuplinkrd import NUUplinkRD
from .nuuser import NUUser
from .nuusercontext import NUUserContext
from .nuvcenter import NUVCenter
from .nuvcentercluster import NUVCenterCluster
from .nuvcenterdatacenter import NUVCenterDataCenter
from .nuvcentereamconfig import NUVCenterEAMConfig
from .nuvcenterhypervisor import NUVCenterHypervisor
from .nuvcentervrsconfig import NUVCenterVRSConfig
from .nuvirtualfirewallpolicy import NUVirtualFirewallPolicy
from .nuvirtualfirewallrule import NUVirtualFirewallRule
from .nuvirtualip import NUVirtualIP
from .nuvirtualuplink import NUVirtualUplink
from .nuvlan import NUVLAN
from .nuvlantemplate import NUVLANTemplate
from .nuvm import NUVM
from .nuvminterface import NUVMInterface
from .nuvmipreservation import NUVMIPReservation
from .nuvmresync import NUVMResync
from .nuvnf import NUVNF
from .nuvnfcatalog import NUVNFCatalog
from .nuvnfdescriptor import NUVNFDescriptor
from .nuvnfdomainmapping import NUVNFDomainMapping
from .nuvnfinterface import NUVNFInterface
from .nuvnfinterfacedescriptor import NUVNFInterfaceDescriptor
from .nuvnfmetadata import NUVNFMetadata
from .nuvnfthresholdpolicy import NUVNFThresholdPolicy
from .nuvpnconnection import NUVPNConnection
from .nuvport import NUVPort
from .nuvportinfo import NUVPortInfo
from .nuvportmirror import NUVPortMirror
from .nuvrs import NUVRS
from .nuvrsaddressrange import NUVRSAddressRange
from .nuvrsinfo import NUvrsInfo
from .nuvrsmetrics import NUVRSMetrics
from .nuvrsredeploymentpolicy import NUVRSRedeploymentpolicy
from .nuvsc import NUVSC
from .nuvsd import NUVSD
from .nuvsdcomponent import NUVSDComponent
from .nuvsdconfig import NUVSDConfig
from .nuvsgredundantport import NUVsgRedundantPort
from .nuvsp import NUVSP
from .nuwanservice import NUWANService
from .nuwebcategory import NUWebCategory
from .nuwebdomainname import NUWebDomainName
from .nuwirelessport import NUWirelessPort
from .nuzfbautoassignment import NUZFBAutoAssignment
from .nuzfbrequest import NUZFBRequest
from .nuzone import NUZone
from .nuzonetemplate import NUZoneTemplate
from .nuvsdsession import NUVSDSession
from .sdkinfo import SDKInfo

def __setup_bambou():
    """ Avoid having bad behavior when using importlib.import_module method
    """
    import pkg_resources
    from bambou import BambouConfig, NURESTModelController

    default_attrs = pkg_resources.resource_filename(__name__, '/resources/attrs_defaults.ini')
    BambouConfig.set_default_values_config_file(default_attrs)

    NURESTModelController.register_model(NUAddressMap)
    NURESTModelController.register_model(NUAddressRange)
    NURESTModelController.register_model(NUAggregatedDomain)
    NURESTModelController.register_model(NUAggregateMetadata)
    NURESTModelController.register_model(NUAlarm)
    NURESTModelController.register_model(NUAllAlarm)
    NURESTModelController.register_model(NUAllGateway)
    NURESTModelController.register_model(NUAllocationPool)
    NURESTModelController.register_model(NUAllRedundancyGroup)
    NURESTModelController.register_model(NUApplication)
    NURESTModelController.register_model(NUApplicationBinding)
    NURESTModelController.register_model(NUApplicationperformancemanagement)
    NURESTModelController.register_model(NUApplicationperformancemanagementbinding)
    NURESTModelController.register_model(NUAutoDiscoverCluster)
    NURESTModelController.register_model(NUAutodiscovereddatacenter)
    NURESTModelController.register_model(NUAutoDiscoveredGateway)
    NURESTModelController.register_model(NUAutoDiscoverHypervisorFromCluster)
    NURESTModelController.register_model(NUAvatar)
    NURESTModelController.register_model(NUAzureCloud)
    NURESTModelController.register_model(NUBandwidthTestResult)
    NURESTModelController.register_model(NUBFDSession)
    NURESTModelController.register_model(NUBGPNeighbor)
    NURESTModelController.register_model(NUBGPPeer)
    NURESTModelController.register_model(NUBGPProfile)
    NURESTModelController.register_model(NUBootstrap)
    NURESTModelController.register_model(NUBootstrapActivation)
    NURESTModelController.register_model(NUBRConnection)
    NURESTModelController.register_model(NUBridgeInterface)
    NURESTModelController.register_model(NUBulkStatistics)
    NURESTModelController.register_model(NUCaptivePortalProfile)
    NURESTModelController.register_model(NUCertificate)
    NURESTModelController.register_model(NUCertificateMetadata)
    NURESTModelController.register_model(NUCloudMgmtSystem)
    NURESTModelController.register_model(NUCommand)
    NURESTModelController.register_model(NUConnectionendpoint)
    NURESTModelController.register_model(NUContainer)
    NURESTModelController.register_model(NUContainerInterface)
    NURESTModelController.register_model(NUContainerResync)
    NURESTModelController.register_model(NUControllerVRSLink)
    NURESTModelController.register_model(NUCOSRemarkingPolicy)
    NURESTModelController.register_model(NUCOSRemarkingPolicyTable)
    NURESTModelController.register_model(NUCSNATPool)
    NURESTModelController.register_model(NUCTranslationMap)
    NURESTModelController.register_model(NUCustomProperty)
    NURESTModelController.register_model(NUDefaultGateway)
    NURESTModelController.register_model(NUDemarcationService)
    NURESTModelController.register_model(NUDeploymentFailure)
    NURESTModelController.register_model(NUDestinationurl)
    NURESTModelController.register_model(NUDHCPOption)
    NURESTModelController.register_model(NUDHCPv6Option)
    NURESTModelController.register_model(NUDiskStat)
    NURESTModelController.register_model(NUDomain)
    NURESTModelController.register_model(NUDomainFIPAclTemplate)
    NURESTModelController.register_model(NUDomainFIPAclTemplateEntry)
    NURESTModelController.register_model(NUDomainKindSummary)
    NURESTModelController.register_model(NUDomainTemplate)
    NURESTModelController.register_model(NUDownloadProgress)
    NURESTModelController.register_model(NUDSCPForwardingClassMapping)
    NURESTModelController.register_model(NUDSCPForwardingClassTable)
    NURESTModelController.register_model(NUDSCPRemarkingPolicy)
    NURESTModelController.register_model(NUDSCPRemarkingPolicyTable)
    NURESTModelController.register_model(NUDUCGroup)
    NURESTModelController.register_model(NUDUCGroupBinding)
    NURESTModelController.register_model(NUEgressACLEntryTemplate)
    NURESTModelController.register_model(NUEgressACLTemplate)
    NURESTModelController.register_model(NUEgressAdvFwdEntryTemplate)
    NURESTModelController.register_model(NUEgressAdvFwdTemplate)
    NURESTModelController.register_model(NUEgressAuditACLEntryTemplate)
    NURESTModelController.register_model(NUEgressAuditACLTemplate)
    NURESTModelController.register_model(NUEgressProfile)
    NURESTModelController.register_model(NUEgressQOSPolicy)
    NURESTModelController.register_model(NUEnterprise)
    NURESTModelController.register_model(NUEnterpriseNetwork)
    NURESTModelController.register_model(NUEnterprisePermission)
    NURESTModelController.register_model(NUEnterpriseProfile)
    NURESTModelController.register_model(NUEnterpriseSecuredData)
    NURESTModelController.register_model(NUEnterpriseSecurity)
    NURESTModelController.register_model(NUEsIlmPolicy)
    NURESTModelController.register_model(NUEsIndexConfig)
    NURESTModelController.register_model(NUEthernetSegmentGroup)
    NURESTModelController.register_model(NUEthernetSegmentGWGroup)
    NURESTModelController.register_model(NUEventLog)
    NURESTModelController.register_model(NUFirewallAcl)
    NURESTModelController.register_model(NUFirewallRule)
    NURESTModelController.register_model(NUFloatingIp)
    NURESTModelController.register_model(NUForwardingClass)
    NURESTModelController.register_model(NUForwardingPathList)
    NURESTModelController.register_model(NUForwardingPathListEntry)
    NURESTModelController.register_model(NUGateway)
    NURESTModelController.register_model(NUGatewayRedundantPort)
    NURESTModelController.register_model(NUGatewaySecuredData)
    NURESTModelController.register_model(NUGatewaySecurity)
    NURESTModelController.register_model(NUGatewaysLocation)
    NURESTModelController.register_model(NUGatewayTemplate)
    NURESTModelController.register_model(NUGlobalMetadata)
    NURESTModelController.register_model(NUGNMIProfile)
    NURESTModelController.register_model(NUGNMISession)
    NURESTModelController.register_model(NUGroup)
    NURESTModelController.register_model(NUGroupKeyEncryptionProfile)
    NURESTModelController.register_model(NUHostInterface)
    NURESTModelController.register_model(NUHSC)
    NURESTModelController.register_model(NUIDPProfile)
    NURESTModelController.register_model(NUIDPProfileAction)
    NURESTModelController.register_model(NUIDPSignature)
    NURESTModelController.register_model(NUIKECertificate)
    NURESTModelController.register_model(NUIKEEncryptionprofile)
    NURESTModelController.register_model(NUIKEGateway)
    NURESTModelController.register_model(NUIKEGatewayConfig)
    NURESTModelController.register_model(NUIKEGatewayConnection)
    NURESTModelController.register_model(NUIKEGatewayProfile)
    NURESTModelController.register_model(NUIKEPSK)
    NURESTModelController.register_model(NUIKESubnet)
    NURESTModelController.register_model(NUInfrastructureAccessProfile)
    NURESTModelController.register_model(NUInfrastructureConfig)
    NURESTModelController.register_model(NUInfrastructureEVDFProfile)
    NURESTModelController.register_model(NUInfrastructureGatewayProfile)
    NURESTModelController.register_model(NUInfrastructureVscProfile)
    NURESTModelController.register_model(NUIngressACLEntryTemplate)
    NURESTModelController.register_model(NUIngressACLTemplate)
    NURESTModelController.register_model(NUIngressAdvFwdEntryTemplate)
    NURESTModelController.register_model(NUIngressAdvFwdTemplate)
    NURESTModelController.register_model(NUIngressAuditACLEntryTemplate)
    NURESTModelController.register_model(NUIngressAuditACLTemplate)
    NURESTModelController.register_model(NUIngressProfile)
    NURESTModelController.register_model(NUIngressQOSPolicy)
    NURESTModelController.register_model(NUIPFilterProfile)
    NURESTModelController.register_model(NUIPReservation)
    NURESTModelController.register_model(NUIPv6FilterProfile)
    NURESTModelController.register_model(NUJob)
    NURESTModelController.register_model(NUKeyServerMember)
    NURESTModelController.register_model(NUKeyServerMonitor)
    NURESTModelController.register_model(NUKeyServerMonitorEncryptedSeed)
    NURESTModelController.register_model(NUKeyServerMonitorSeed)
    NURESTModelController.register_model(NUKeyServerMonitorSEK)
    NURESTModelController.register_model(NUL2Domain)
    NURESTModelController.register_model(NUL2DomainTemplate)
    NURESTModelController.register_model(NUL4Service)
    NURESTModelController.register_model(NUL4ServiceGroup)
    NURESTModelController.register_model(NUL7applicationsignature)
    NURESTModelController.register_model(NULDAPConfiguration)
    NURESTModelController.register_model(NULicense)
    NURESTModelController.register_model(NULicenseStatus)
    NURESTModelController.register_model(NULink)
    NURESTModelController.register_model(NULocation)
    NURESTModelController.register_model(NULTEInformation)
    NURESTModelController.register_model(NULtestatistics)
    NURESTModelController.register_model(NUMACFilterProfile)
    NURESTModelController.register_model(NUMe)
    NURESTModelController.register_model(NUMetadata)
    NURESTModelController.register_model(NUMirrorDestination)
    NURESTModelController.register_model(NUMirrorDestinationGroup)
    NURESTModelController.register_model(NUMonitoringPort)
    NURESTModelController.register_model(NUMonitorscope)
    NURESTModelController.register_model(NUMTUDiscoveryTestResult)
    NURESTModelController.register_model(NUMultiCastChannelMap)
    NURESTModelController.register_model(NUMultiCastList)
    NURESTModelController.register_model(NUMultiCastRange)
    NURESTModelController.register_model(NUMultiNICVPort)
    NURESTModelController.register_model(NUNATMapEntry)
    NURESTModelController.register_model(NUNetconfGateway)
    NURESTModelController.register_model(NUNetconfManager)
    NURESTModelController.register_model(NUNetconfProfile)
    NURESTModelController.register_model(NUNetconfSession)
    NURESTModelController.register_model(NUNetworkLayout)
    NURESTModelController.register_model(NUNetworkMacroGroup)
    NURESTModelController.register_model(NUNetworkPerformanceBinding)
    NURESTModelController.register_model(NUNetworkPerformanceMeasurement)
    NURESTModelController.register_model(NUNextHop)
    NURESTModelController.register_model(NUNSGateway)
    NURESTModelController.register_model(NUNSGatewayMonitor)
    NURESTModelController.register_model(NUNSGatewaysCount)
    NURESTModelController.register_model(NUNSGatewaySummary)
    NURESTModelController.register_model(NUNSGatewayTemplate)
    NURESTModelController.register_model(NUNSGGroup)
    NURESTModelController.register_model(NUNSGInfo)
    NURESTModelController.register_model(NUNSGPatchProfile)
    NURESTModelController.register_model(NUNSGRoutingPolicyBinding)
    NURESTModelController.register_model(NUNSGUpgradeProfile)
    NURESTModelController.register_model(NUNSPort)
    NURESTModelController.register_model(NUNSPortInfo)
    NURESTModelController.register_model(NUNSPortTemplate)
    NURESTModelController.register_model(NUNSRedundantGatewayGroup)
    NURESTModelController.register_model(NUOSPFArea)
    NURESTModelController.register_model(NUOSPFInstance)
    NURESTModelController.register_model(NUOSPFInterface)
    NURESTModelController.register_model(NUOverlayAddressPool)
    NURESTModelController.register_model(NUOverlayManagementProfile)
    NURESTModelController.register_model(NUOverlayManagementSubnetProfile)
    NURESTModelController.register_model(NUOverlayMirrorDestination)
    NURESTModelController.register_model(NUOverlayMirrorDestinationTemplate)
    NURESTModelController.register_model(NUOverlayPATNATEntry)
    NURESTModelController.register_model(NUPatch)
    NURESTModelController.register_model(NUPATIPEntry)
    NURESTModelController.register_model(NUPATMapper)
    NURESTModelController.register_model(NUPATNATPool)
    NURESTModelController.register_model(NUPerformanceMonitor)
    NURESTModelController.register_model(NUPermission)
    NURESTModelController.register_model(NUPGExpression)
    NURESTModelController.register_model(NUPGExpressionTemplate)
    NURESTModelController.register_model(NUPolicyDecision)
    NURESTModelController.register_model(NUPolicyEntry)
    NURESTModelController.register_model(NUPolicyGroup)
    NURESTModelController.register_model(NUPolicyGroupCategory)
    NURESTModelController.register_model(NUPolicyGroupTemplate)
    NURESTModelController.register_model(NUPolicyObjectGroup)
    NURESTModelController.register_model(NUPolicyStatement)
    NURESTModelController.register_model(NUPort)
    NURESTModelController.register_model(NUPortMapping)
    NURESTModelController.register_model(NUPortTemplate)
    NURESTModelController.register_model(NUProxyARPFilter)
    NURESTModelController.register_model(NUPSNATPool)
    NURESTModelController.register_model(NUPSPATMap)
    NURESTModelController.register_model(NUPTranslationMap)
    NURESTModelController.register_model(NUPublicNetworkMacro)
    NURESTModelController.register_model(NUQOS)
    NURESTModelController.register_model(NUQosPolicer)
    NURESTModelController.register_model(NURateLimiter)
    NURESTModelController.register_model(NURedirectionTarget)
    NURESTModelController.register_model(NURedirectionTargetTemplate)
    NURESTModelController.register_model(NURedundancyGroup)
    NURESTModelController.register_model(NURedundantPort)
    NURESTModelController.register_model(NURemoteVrsInfo)
    NURESTModelController.register_model(NURole)
    NURESTModelController.register_model(NURoleentry)
    NURESTModelController.register_model(NURoutingPolicy)
    NURESTModelController.register_model(NURoutingPolicyBinding)
    NURESTModelController.register_model(NUSaaSApplicationGroup)
    NURESTModelController.register_model(NUSaaSApplicationType)
    NURESTModelController.register_model(NUSAPEgressQoSProfile)
    NURESTModelController.register_model(NUSAPIngressQoSProfile)
    NURESTModelController.register_model(NUSharedNetworkResource)
    NURESTModelController.register_model(NUShuntLink)
    NURESTModelController.register_model(NUSiteInfo)
    NURESTModelController.register_model(NUSPATSourcesPool)
    NURESTModelController.register_model(NUSSHKey)
    NURESTModelController.register_model(NUSSIDConnection)
    NURESTModelController.register_model(NUStaticRoute)
    NURESTModelController.register_model(NUStatistics)
    NURESTModelController.register_model(NUStatisticsPolicy)
    NURESTModelController.register_model(NUStatsCollectorInfo)
    NURESTModelController.register_model(NUSubnet)
    NURESTModelController.register_model(NUSubnetTemplate)
    NURESTModelController.register_model(NUSupplementalInfraConfig)
    NURESTModelController.register_model(NUSyslogDestination)
    NURESTModelController.register_model(NUSysmonUplinkConnection)
    NURESTModelController.register_model(NUSystemConfig)
    NURESTModelController.register_model(NUTCA)
    NURESTModelController.register_model(NUTCPConnectTestResult)
    NURESTModelController.register_model(NUTest)
    NURESTModelController.register_model(NUTestDefinition)
    NURESTModelController.register_model(NUTestRun)
    NURESTModelController.register_model(NUTestSuite)
    NURESTModelController.register_model(NUTestSuiteRun)
    NURESTModelController.register_model(NUThreatPreventionInfo)
    NURESTModelController.register_model(NUThreatPreventionNodeInfo)
    NURESTModelController.register_model(NUThreatPreventionServerConnection)
    NURESTModelController.register_model(NUTier)
    NURESTModelController.register_model(NUTrunk)
    NURESTModelController.register_model(NUUDPProbeTestResult)
    NURESTModelController.register_model(NUUnderlay)
    NURESTModelController.register_model(NUUnderlayTest)
    NURESTModelController.register_model(NUUplinkConnection)
    NURESTModelController.register_model(NUUplinkRD)
    NURESTModelController.register_model(NUUser)
    NURESTModelController.register_model(NUUserContext)
    NURESTModelController.register_model(NUVCenter)
    NURESTModelController.register_model(NUVCenterCluster)
    NURESTModelController.register_model(NUVCenterDataCenter)
    NURESTModelController.register_model(NUVCenterEAMConfig)
    NURESTModelController.register_model(NUVCenterHypervisor)
    NURESTModelController.register_model(NUVCenterVRSConfig)
    NURESTModelController.register_model(NUVirtualFirewallPolicy)
    NURESTModelController.register_model(NUVirtualFirewallRule)
    NURESTModelController.register_model(NUVirtualIP)
    NURESTModelController.register_model(NUVirtualUplink)
    NURESTModelController.register_model(NUVLAN)
    NURESTModelController.register_model(NUVLANTemplate)
    NURESTModelController.register_model(NUVM)
    NURESTModelController.register_model(NUVMInterface)
    NURESTModelController.register_model(NUVMIPReservation)
    NURESTModelController.register_model(NUVMResync)
    NURESTModelController.register_model(NUVNF)
    NURESTModelController.register_model(NUVNFCatalog)
    NURESTModelController.register_model(NUVNFDescriptor)
    NURESTModelController.register_model(NUVNFDomainMapping)
    NURESTModelController.register_model(NUVNFInterface)
    NURESTModelController.register_model(NUVNFInterfaceDescriptor)
    NURESTModelController.register_model(NUVNFMetadata)
    NURESTModelController.register_model(NUVNFThresholdPolicy)
    NURESTModelController.register_model(NUVPNConnection)
    NURESTModelController.register_model(NUVPort)
    NURESTModelController.register_model(NUVPortInfo)
    NURESTModelController.register_model(NUVPortMirror)
    NURESTModelController.register_model(NUVRS)
    NURESTModelController.register_model(NUVRSAddressRange)
    NURESTModelController.register_model(NUvrsInfo)
    NURESTModelController.register_model(NUVRSMetrics)
    NURESTModelController.register_model(NUVRSRedeploymentpolicy)
    NURESTModelController.register_model(NUVSC)
    NURESTModelController.register_model(NUVSD)
    NURESTModelController.register_model(NUVSDComponent)
    NURESTModelController.register_model(NUVSDConfig)
    NURESTModelController.register_model(NUVsgRedundantPort)
    NURESTModelController.register_model(NUVSP)
    NURESTModelController.register_model(NUWANService)
    NURESTModelController.register_model(NUWebCategory)
    NURESTModelController.register_model(NUWebDomainName)
    NURESTModelController.register_model(NUWirelessPort)
    NURESTModelController.register_model(NUZFBAutoAssignment)
    NURESTModelController.register_model(NUZFBRequest)
    NURESTModelController.register_model(NUZone)
    NURESTModelController.register_model(NUZoneTemplate)
    

__setup_bambou()


# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.



from bambou import NURESTObject


class NUThreatPreventionInfo(NURESTObject):
    """ Represents a ThreatPreventionInfo in the VSD

        Notes:
            Represents information about Threat Prevention service/instance on NSG. This is read only entity.
    """

    __rest_name__ = "threatpreventioninfo"
    __resource_name__ = "threatpreventioninfos"

    
    ## Constants
    
    CONST_CONFIGURATION_STATUS_REGISTRATION_FAILED = "REGISTRATION_FAILED"
    
    CONST_SERVICE_STATUS_SHUTOFF = "SHUTOFF"
    
    CONST_CONFIGURATION_STATUS_CONFIG_FAILED = "CONFIG_FAILED"
    
    CONST_SERVICE_STATUS_RUNNING = "RUNNING"
    
    CONST_SERVICE_STATUS_IDLE = "IDLE"
    
    CONST_MANAGEMENT_SERVER_CONNECTION_STATUS_NOT_APPLICABLE = "NOT_APPLICABLE"
    
    CONST_SERVICE_STATUS_DYING = "DYING"
    
    CONST_SERVICE_STATUS_CRASHED = "CRASHED"
    
    CONST_CONFIGURATION_STATUS_ACTIVATION_FAILED = "ACTIVATION_FAILED"
    
    CONST_CONFIGURATION_STATUS_SYNCED = "SYNCED"
    
    CONST_SERVICE_STATUS_PAUSED = "PAUSED"
    
    CONST_MANAGEMENT_SERVER_CONNECTION_STATUS_CONNECTED = "CONNECTED"
    
    CONST_SERVICE_STATUS_BLOCKED = "BLOCKED"
    
    CONST_CONFIGURATION_STATUS_NOT_APPLICABLE = "NOT_APPLICABLE"
    
    CONST_SERVICE_STATUS_SHUTDOWN = "SHUTDOWN"
    
    CONST_MANAGEMENT_SERVER_CONNECTION_STATUS_DISCONNECTED = "DISCONNECTED"
    
    CONST_SERVICE_STATUS_LAST = "LAST"
    
    CONST_SERVICE_STATUS_INIT = "INIT"
    
    CONST_SERVICE_STATUS_PMSUSPENDED = "PMSUSPENDED"
    
    

    def __init__(self, **kwargs):
        """ Initializes a ThreatPreventionInfo instance

            Notes:
                You can specify all parameters while calling this methods.
                A special argument named `data` will enable you to load the
                object from a Python dictionary

            Examples:
                >>> threatpreventioninfo = NUThreatPreventionInfo(id=u'xxxx-xxx-xxx-xxx', name=u'ThreatPreventionInfo')
                >>> threatpreventioninfo = NUThreatPreventionInfo(data=my_dict)
        """

        super(NUThreatPreventionInfo, self).__init__()

        # Read/Write Attributes
        
        self._management_server_connection_status = None
        self._service_status = None
        self._configuration_status = None
        
        self.expose_attribute(local_name="management_server_connection_status", remote_name="managementServerConnectionStatus", attribute_type=str, is_required=False, is_unique=False, choices=[u'CONNECTED', u'DISCONNECTED', u'NOT_APPLICABLE'])
        self.expose_attribute(local_name="service_status", remote_name="serviceStatus", attribute_type=str, is_required=False, is_unique=False, choices=[u'BLOCKED', u'CRASHED', u'DYING', u'IDLE', u'INIT', u'LAST', u'PAUSED', u'PMSUSPENDED', u'RUNNING', u'SHUTDOWN', u'SHUTOFF'])
        self.expose_attribute(local_name="configuration_status", remote_name="configurationStatus", attribute_type=str, is_required=False, is_unique=False, choices=[u'ACTIVATION_FAILED', u'CONFIG_FAILED', u'NOT_APPLICABLE', u'REGISTRATION_FAILED', u'SYNCED'])
        

        self._compute_args(**kwargs)

    # Properties
    
    @property
    def management_server_connection_status(self):
        """ Get management_server_connection_status value.

            Notes:
                Connection status between Threat Prevention manaement Server and NSG.

                
                This attribute is named `managementServerConnectionStatus` in VSD API.
                
        """
        return self._management_server_connection_status

    @management_server_connection_status.setter
    def management_server_connection_status(self, value):
        """ Set management_server_connection_status value.

            Notes:
                Connection status between Threat Prevention manaement Server and NSG.

                
                This attribute is named `managementServerConnectionStatus` in VSD API.
                
        """
        self._management_server_connection_status = value

    
    @property
    def service_status(self):
        """ Get service_status value.

            Notes:
                Status of Threat prevention service/instance on NSG.

                
                This attribute is named `serviceStatus` in VSD API.
                
        """
        return self._service_status

    @service_status.setter
    def service_status(self, value):
        """ Set service_status value.

            Notes:
                Status of Threat prevention service/instance on NSG.

                
                This attribute is named `serviceStatus` in VSD API.
                
        """
        self._service_status = value

    
    @property
    def configuration_status(self):
        """ Get configuration_status value.

            Notes:
                VSD Configuration status for Threat Prevention service on NSG.

                
                This attribute is named `configurationStatus` in VSD API.
                
        """
        return self._configuration_status

    @configuration_status.setter
    def configuration_status(self, value):
        """ Set configuration_status value.

            Notes:
                VSD Configuration status for Threat Prevention service on NSG.

                
                This attribute is named `configurationStatus` in VSD API.
                
        """
        self._configuration_status = value

    

    


# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.



from bambou import NURESTObject


class NUIDPProfileAction(NURESTObject):
    """ Represents a IDPProfileAction in the VSD

        Notes:
            An IDP Profile/Rule Action specifies what signatures to search for in the network traffic, and what action to take if those signatures are found.
    """

    __rest_name__ = "idpprofileaction"
    __resource_name__ = "idpprofileactions"

    
    ## Constants
    
    CONST_ACTION_PROTECT = "PROTECT"
    
    CONST_ACTION_AUDIT = "AUDIT"
    
    

    def __init__(self, **kwargs):
        """ Initializes a IDPProfileAction instance

            Notes:
                You can specify all parameters while calling this methods.
                A special argument named `data` will enable you to load the
                object from a Python dictionary

            Examples:
                >>> idpprofileaction = NUIDPProfileAction(id=u'xxxx-xxx-xxx-xxx', name=u'IDPProfileAction')
                >>> idpprofileaction = NUIDPProfileAction(data=my_dict)
        """

        super(NUIDPProfileAction, self).__init__()

        # Read/Write Attributes
        
        self._idp_signatures = None
        self._action = None
        self._priority = None
        self._associated_idp_profile_id = None
        
        self.expose_attribute(local_name="idp_signatures", remote_name="IDPSignatures", attribute_type=list, is_required=False, is_unique=False)
        self.expose_attribute(local_name="action", remote_name="action", attribute_type=str, is_required=False, is_unique=False, choices=[u'AUDIT', u'PROTECT'])
        self.expose_attribute(local_name="priority", remote_name="priority", attribute_type=int, is_required=False, is_unique=False)
        self.expose_attribute(local_name="associated_idp_profile_id", remote_name="associatedIDPProfileID", attribute_type=str, is_required=False, is_unique=False)
        

        self._compute_args(**kwargs)

    # Properties
    
    @property
    def idp_signatures(self):
        """ Get idp_signatures value.

            Notes:
                IDP Signatures to search in network traffic

                
                This attribute is named `IDPSignatures` in VSD API.
                
        """
        return self._idp_signatures

    @idp_signatures.setter
    def idp_signatures(self, value):
        """ Set idp_signatures value.

            Notes:
                IDP Signatures to search in network traffic

                
                This attribute is named `IDPSignatures` in VSD API.
                
        """
        self._idp_signatures = value

    
    @property
    def action(self):
        """ Get action value.

            Notes:
                Specifies what action to take if given signatures is found

                
        """
        return self._action

    @action.setter
    def action(self, value):
        """ Set action value.

            Notes:
                Specifies what action to take if given signatures is found

                
        """
        self._action = value

    
    @property
    def priority(self):
        """ Get priority value.

            Notes:
                The priority determines the order of IDP action

                
        """
        return self._priority

    @priority.setter
    def priority(self, value):
        """ Set priority value.

            Notes:
                The priority determines the order of IDP action

                
        """
        self._priority = value

    
    @property
    def associated_idp_profile_id(self):
        """ Get associated_idp_profile_id value.

            Notes:
                The ID of the associated IDP Profile

                
                This attribute is named `associatedIDPProfileID` in VSD API.
                
        """
        return self._associated_idp_profile_id

    @associated_idp_profile_id.setter
    def associated_idp_profile_id(self, value):
        """ Set associated_idp_profile_id value.

            Notes:
                The ID of the associated IDP Profile

                
                This attribute is named `associatedIDPProfileID` in VSD API.
                
        """
        self._associated_idp_profile_id = value

    

    


# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.




from .fetchers import NUDeploymentFailuresFetcher


from .fetchers import NUMetadatasFetcher


from .fetchers import NUGlobalMetadatasFetcher

from bambou import NURESTObject


class NUBGPNeighbor(NURESTObject):
    """ Represents a BGPNeighbor in the VSD

        Notes:
            Virtual Cloud Services (VCS) in the data center BGP PE-CE is configured at vport level . Network Service Gateways (NSG) BGP is configured at subnet level.
    """

    __rest_name__ = "bgpneighbor"
    __resource_name__ = "bgpneighbors"

    
    ## Constants
    
    CONST_IP_TYPE_IPV6 = "IPV6"
    
    CONST_IP_TYPE_IPV4 = "IPV4"
    
    CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
    
    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
    
    

    def __init__(self, **kwargs):
        """ Initializes a BGPNeighbor instance

            Notes:
                You can specify all parameters while calling this methods.
                A special argument named `data` will enable you to load the
                object from a Python dictionary

            Examples:
                >>> bgpneighbor = NUBGPNeighbor(id=u'xxxx-xxx-xxx-xxx', name=u'BGPNeighbor')
                >>> bgpneighbor = NUBGPNeighbor(data=my_dict)
        """

        super(NUBGPNeighbor, self).__init__()

        # Read/Write Attributes
        
        self._bfd_enabled = None
        self._ip_type = None
        self._ipv6_address = None
        self._name = None
        self._dampening_enabled = None
        self._peer_as = None
        self._peer_configuration = None
        self._peer_ip = None
        self._description = None
        self._session = None
        self._entity_scope = None
        self._domain_service_label = None
        self._associated_export_routing_policy_id = None
        self._associated_import_routing_policy_id = None
        self._external_id = None
        
        self.expose_attribute(local_name="bfd_enabled", remote_name="BFDEnabled", attribute_type=bool, is_required=False, is_unique=False)
        self.expose_attribute(local_name="ip_type", remote_name="IPType", attribute_type=str, is_required=False, is_unique=False, choices=[u'IPV4', u'IPV6'])
        self.expose_attribute(local_name="ipv6_address", remote_name="IPv6Address", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
        self.expose_attribute(local_name="dampening_enabled", remote_name="dampeningEnabled", attribute_type=bool, is_required=False, is_unique=False)
        self.expose_attribute(local_name="peer_as", remote_name="peerAS", attribute_type=int, is_required=True, is_unique=False)
        self.expose_attribute(local_name="peer_configuration", remote_name="peerConfiguration", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="peer_ip", remote_name="peerIP", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="session", remote_name="session", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
        self.expose_attribute(local_name="domain_service_label", remote_name="domainServiceLabel", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="associated_export_routing_policy_id", remote_name="associatedExportRoutingPolicyID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="associated_import_routing_policy_id", remote_name="associatedImportRoutingPolicyID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
        

        # Fetchers
        
        
        self.deployment_failures = NUDeploymentFailuresFetcher.fetcher_with_object(parent_object=self, relationship="child")
        
        
        self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
        
        
        self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
        

        self._compute_args(**kwargs)

    # Properties
    
    @property
    def bfd_enabled(self):
        """ Get bfd_enabled value.

            Notes:
                Enable or disable Bidirectional Forwarding Detection for this BGP neighbor

                
                This attribute is named `BFDEnabled` in VSD API.
                
        """
        return self._bfd_enabled

    @bfd_enabled.setter
    def bfd_enabled(self, value):
        """ Set bfd_enabled value.

            Notes:
                Enable or disable Bidirectional Forwarding Detection for this BGP neighbor

                
                This attribute is named `BFDEnabled` in VSD API.
                
        """
        self._bfd_enabled = value

    
    @property
    def ip_type(self):
        """ Get ip_type value.

            Notes:
                It can be either IPv4 or IPv6

                
                This attribute is named `IPType` in VSD API.
                
        """
        return self._ip_type

    @ip_type.setter
    def ip_type(self, value):
        """ Set ip_type value.

            Notes:
                It can be either IPv4 or IPv6

                
                This attribute is named `IPType` in VSD API.
                
        """
        self._ip_type = value

    
    @property
    def ipv6_address(self):
        """ Get ipv6_address value.

            Notes:
                Peer IPv6 address

                
                This attribute is named `IPv6Address` in VSD API.
                
        """
        return self._ipv6_address

    @ipv6_address.setter
    def ipv6_address(self, value):
        """ Set ipv6_address value.

            Notes:
                Peer IPv6 address

                
                This attribute is named `IPv6Address` in VSD API.
                
        """
        self._ipv6_address = value

    
    @property
    def name(self):
        """ Get name value.

            Notes:
                Name of the peer

                
        """
        return self._name

    @name.setter
    def name(self, value):
        """ Set name value.

            Notes:
                Name of the peer

                
        """
        self._name = value

    
    @property
    def dampening_enabled(self):
        """ Get dampening_enabled value.

            Notes:
                Enable/disable route flap damping.

                
                This attribute is named `dampeningEnabled` in VSD API.
                
        """
        return self._dampening_enabled

    @dampening_enabled.setter
    def dampening_enabled(self, value):
        """ Set dampening_enabled value.

            Notes:
                Enable/disable route flap damping.

                
                This attribute is named `dampeningEnabled` in VSD API.
                
        """
        self._dampening_enabled = value

    
    @property
    def peer_as(self):
        """ Get peer_as value.

            Notes:
                Autonomous System (AS) value to be used when establishing a session with the remote peer if it is different from the global BGP router autonomous system number.

                
                This attribute is named `peerAS` in VSD API.
                
        """
        return self._peer_as

    @peer_as.setter
    def peer_as(self, value):
        """ Set peer_as value.

            Notes:
                Autonomous System (AS) value to be used when establishing a session with the remote peer if it is different from the global BGP router autonomous system number.

                
                This attribute is named `peerAS` in VSD API.
                
        """
        self._peer_as = value

    
    @property
    def peer_configuration(self):
        """ Get peer_configuration value.

            Notes:
                BGP Peer session configuration and default policies.

                
                This attribute is named `peerConfiguration` in VSD API.
                
        """
        return self._peer_configuration

    @peer_configuration.setter
    def peer_configuration(self, value):
        """ Set peer_configuration value.

            Notes:
                BGP Peer session configuration and default policies.

                
                This attribute is named `peerConfiguration` in VSD API.
                
        """
        self._peer_configuration = value

    
    @property
    def peer_ip(self):
        """ Get peer_ip value.

            Notes:
                IP Address of the neighbor. If the neighbor is attached to a host vPort this is optional or must be the same as the host's IP. For uplink or bridge vPort neighbors the IP address must be specified 

                
                This attribute is named `peerIP` in VSD API.
                
        """
        return self._peer_ip

    @peer_ip.setter
    def peer_ip(self, value):
        """ Set peer_ip value.

            Notes:
                IP Address of the neighbor. If the neighbor is attached to a host vPort this is optional or must be the same as the host's IP. For uplink or bridge vPort neighbors the IP address must be specified 

                
                This attribute is named `peerIP` in VSD API.
                
        """
        self._peer_ip = value

    
    @property
    def description(self):
        """ Get description value.

            Notes:
                Short description for this peer

                
        """
        return self._description

    @description.setter
    def description(self, value):
        """ Set description value.

            Notes:
                Short description for this peer

                
        """
        self._description = value

    
    @property
    def session(self):
        """ Get session value.

            Notes:
                neighbor session yang blob

                
        """
        return self._session

    @session.setter
    def session(self, value):
        """ Set session value.

            Notes:
                neighbor session yang blob

                
        """
        self._session = value

    
    @property
    def entity_scope(self):
        """ Get entity_scope value.

            Notes:
                Specify if scope of entity is Data center or Enterprise level

                
                This attribute is named `entityScope` in VSD API.
                
        """
        return self._entity_scope

    @entity_scope.setter
    def entity_scope(self, value):
        """ Set entity_scope value.

            Notes:
                Specify if scope of entity is Data center or Enterprise level

                
                This attribute is named `entityScope` in VSD API.
                
        """
        self._entity_scope = value

    
    @property
    def domain_service_label(self):
        """ Get domain_service_label value.

            Notes:
                Service ID or external label given to Domain

                
                This attribute is named `domainServiceLabel` in VSD API.
                
        """
        return self._domain_service_label

    @domain_service_label.setter
    def domain_service_label(self, value):
        """ Set domain_service_label value.

            Notes:
                Service ID or external label given to Domain

                
                This attribute is named `domainServiceLabel` in VSD API.
                
        """
        self._domain_service_label = value

    
    @property
    def associated_export_routing_policy_id(self):
        """ Get associated_export_routing_policy_id value.

            Notes:
                export policy ID

                
                This attribute is named `associatedExportRoutingPolicyID` in VSD API.
                
        """
        return self._associated_export_routing_policy_id

    @associated_export_routing_policy_id.setter
    def associated_export_routing_policy_id(self, value):
        """ Set associated_export_routing_policy_id value.

            Notes:
                export policy ID

                
                This attribute is named `associatedExportRoutingPolicyID` in VSD API.
                
        """
        self._associated_export_routing_policy_id = value

    
    @property
    def associated_import_routing_policy_id(self):
        """ Get associated_import_routing_policy_id value.

            Notes:
                import routing policy ID

                
                This attribute is named `associatedImportRoutingPolicyID` in VSD API.
                
        """
        return self._associated_import_routing_policy_id

    @associated_import_routing_policy_id.setter
    def associated_import_routing_policy_id(self, value):
        """ Set associated_import_routing_policy_id value.

            Notes:
                import routing policy ID

                
                This attribute is named `associatedImportRoutingPolicyID` in VSD API.
                
        """
        self._associated_import_routing_policy_id = value

    
    @property
    def external_id(self):
        """ Get external_id value.

            Notes:
                External object ID. Used for integration with third party systems

                
                This attribute is named `externalID` in VSD API.
                
        """
        return self._external_id

    @external_id.setter
    def external_id(self, value):
        """ Set external_id value.

            Notes:
                External object ID. Used for integration with third party systems

                
                This attribute is named `externalID` in VSD API.
                
        """
        self._external_id = value

    

    


# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.




from .fetchers import NUMetadatasFetcher


from .fetchers import NUGlobalMetadatasFetcher

from bambou import NURESTObject


class NUOSPFInterface(NURESTObject):
    """ Represents a OSPFInterface in the VSD

        Notes:
            The OSPF interface represents the connection of a router to the OSPF network. The OSPF interface defines the protocol metrics and security parameters for OSPF traffic on a V-Port on the specified subnet. An OSPF interface can exist in only one OSPF area.
    """

    __rest_name__ = "ospfinterface"
    __resource_name__ = "ospfinterfaces"

    
    ## Constants
    
    CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
    
    CONST_INTERFACE_TYPE_POINT_TO_POINT = "POINT_TO_POINT"
    
    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
    
    CONST_ADMIN_STATE_DOWN = "DOWN"
    
    CONST_AUTHENTICATION_TYPE_MESSAGE_DIGEST = "MESSAGE_DIGEST"
    
    CONST_ADMIN_STATE_UP = "UP"
    
    CONST_INTERFACE_TYPE_BROADCAST = "BROADCAST"
    
    CONST_AUTHENTICATION_TYPE_PASSWORD = "PASSWORD"
    
    CONST_AUTHENTICATION_TYPE_NONE = "NONE"
    
    

    def __init__(self, **kwargs):
        """ Initializes a OSPFInterface instance

            Notes:
                You can specify all parameters while calling this methods.
                A special argument named `data` will enable you to load the
                object from a Python dictionary

            Examples:
                >>> ospfinterface = NUOSPFInterface(id=u'xxxx-xxx-xxx-xxx', name=u'OSPFInterface')
                >>> ospfinterface = NUOSPFInterface(data=my_dict)
        """

        super(NUOSPFInterface, self).__init__()

        # Read/Write Attributes
        
        self._name = None
        self._passive_enabled = None
        self._last_updated_by = None
        self._admin_state = None
        self._dead_interval = None
        self._hello_interval = None
        self._description = None
        self._message_digest_keys = None
        self._metric = None
        self._interface_type = None
        self._entity_scope = None
        self._priority = None
        self._associated_subnet_id = None
        self._mtu = None
        self._authentication_key = None
        self._authentication_type = None
        self._external_id = None
        
        self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
        self.expose_attribute(local_name="passive_enabled", remote_name="passiveEnabled", attribute_type=bool, is_required=False, is_unique=False)
        self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="admin_state", remote_name="adminState", attribute_type=str, is_required=False, is_unique=False, choices=[u'DOWN', u'UP'])
        self.expose_attribute(local_name="dead_interval", remote_name="deadInterval", attribute_type=int, is_required=False, is_unique=False)
        self.expose_attribute(local_name="hello_interval", remote_name="helloInterval", attribute_type=int, is_required=False, is_unique=False)
        self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="message_digest_keys", remote_name="messageDigestKeys", attribute_type=list, is_required=False, is_unique=False)
        self.expose_attribute(local_name="metric", remote_name="metric", attribute_type=int, is_required=False, is_unique=False)
        self.expose_attribute(local_name="interface_type", remote_name="interfaceType", attribute_type=str, is_required=False, is_unique=False, choices=[u'BROADCAST', u'POINT_TO_POINT'])
        self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
        self.expose_attribute(local_name="priority", remote_name="priority", attribute_type=int, is_required=False, is_unique=False)
        self.expose_attribute(local_name="associated_subnet_id", remote_name="associatedSubnetID", attribute_type=str, is_required=True, is_unique=False)
        self.expose_attribute(local_name="mtu", remote_name="mtu", attribute_type=int, is_required=False, is_unique=False)
        self.expose_attribute(local_name="authentication_key", remote_name="authenticationKey", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="authentication_type", remote_name="authenticationType", attribute_type=str, is_required=False, is_unique=False, choices=[u'MESSAGE_DIGEST', u'NONE', u'PASSWORD'])
        self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
        

        # Fetchers
        
        
        self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
        
        
        self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
        

        self._compute_args(**kwargs)

    # Properties
    
    @property
    def name(self):
        """ Get name value.

            Notes:
                Name of the OSPF Interface. The name has to be unique within the OSPFArea.

                
        """
        return self._name

    @name.setter
    def name(self, value):
        """ Set name value.

            Notes:
                Name of the OSPF Interface. The name has to be unique within the OSPFArea.

                
        """
        self._name = value

    
    @property
    def passive_enabled(self):
        """ Get passive_enabled value.

            Notes:
                Enable the passive property of the interface.

                
                This attribute is named `passiveEnabled` in VSD API.
                
        """
        return self._passive_enabled

    @passive_enabled.setter
    def passive_enabled(self, value):
        """ Set passive_enabled value.

            Notes:
                Enable the passive property of the interface.

                
                This attribute is named `passiveEnabled` in VSD API.
                
        """
        self._passive_enabled = value

    
    @property
    def last_updated_by(self):
        """ Get last_updated_by value.

            Notes:
                ID of the user who last updated the object.

                
                This attribute is named `lastUpdatedBy` in VSD API.
                
        """
        return self._last_updated_by

    @last_updated_by.setter
    def last_updated_by(self, value):
        """ Set last_updated_by value.

            Notes:
                ID of the user who last updated the object.

                
                This attribute is named `lastUpdatedBy` in VSD API.
                
        """
        self._last_updated_by = value

    
    @property
    def admin_state(self):
        """ Get admin_state value.

            Notes:
                Admin state of this OSPF interface

                
                This attribute is named `adminState` in VSD API.
                
        """
        return self._admin_state

    @admin_state.setter
    def admin_state(self, value):
        """ Set admin_state value.

            Notes:
                Admin state of this OSPF interface

                
                This attribute is named `adminState` in VSD API.
                
        """
        self._admin_state = value

    
    @property
    def dead_interval(self):
        """ Get dead_interval value.

            Notes:
                Time OSPF waits without receiving hello packets before declaring a neighbor down. If specified, it must be at least twice as long as 'helloInterval'.

                
                This attribute is named `deadInterval` in VSD API.
                
        """
        return self._dead_interval

    @dead_interval.setter
    def dead_interval(self, value):
        """ Set dead_interval value.

            Notes:
                Time OSPF waits without receiving hello packets before declaring a neighbor down. If specified, it must be at least twice as long as 'helloInterval'.

                
                This attribute is named `deadInterval` in VSD API.
                
        """
        self._dead_interval = value

    
    @property
    def hello_interval(self):
        """ Get hello_interval value.

            Notes:
                Time interval between OSPF hellos issued on the interface.

                
                This attribute is named `helloInterval` in VSD API.
                
        """
        return self._hello_interval

    @hello_interval.setter
    def hello_interval(self, value):
        """ Set hello_interval value.

            Notes:
                Time interval between OSPF hellos issued on the interface.

                
                This attribute is named `helloInterval` in VSD API.
                
        """
        self._hello_interval = value

    
    @property
    def description(self):
        """ Get description value.

            Notes:
                Description of this OSPF Interface.

                
        """
        return self._description

    @description.setter
    def description(self, value):
        """ Set description value.

            Notes:
                Description of this OSPF Interface.

                
        """
        self._description = value

    
    @property
    def message_digest_keys(self):
        """ Get message_digest_keys value.

            Notes:
                This attribute applies only when 'authenticationType' is 'MESSAGE_DIGEST'. In that case, this attribute is a list of pairs of key ID/password used for MD5 authentication. The key ID must by an integer between 1 and 255, and the value is a password (of 16 charachters maximum) used to generate an MD5 hash. The MD5 has is then used as authentication data in the OSPF packets. No duplicate key IDs are allowed. The format for each pair is 'keyID:password' (e.g. '1:foobar')

                
                This attribute is named `messageDigestKeys` in VSD API.
                
        """
        return self._message_digest_keys

    @message_digest_keys.setter
    def message_digest_keys(self, value):
        """ Set message_digest_keys value.

            Notes:
                This attribute applies only when 'authenticationType' is 'MESSAGE_DIGEST'. In that case, this attribute is a list of pairs of key ID/password used for MD5 authentication. The key ID must by an integer between 1 and 255, and the value is a password (of 16 charachters maximum) used to generate an MD5 hash. The MD5 has is then used as authentication data in the OSPF packets. No duplicate key IDs are allowed. The format for each pair is 'keyID:password' (e.g. '1:foobar')

                
                This attribute is named `messageDigestKeys` in VSD API.
                
        """
        self._message_digest_keys = value

    
    @property
    def metric(self):
        """ Get metric value.

            Notes:
                Configure an explicit route cost metric for the interface.

                
        """
        return self._metric

    @metric.setter
    def metric(self, value):
        """ Set metric value.

            Notes:
                Configure an explicit route cost metric for the interface.

                
        """
        self._metric = value

    
    @property
    def interface_type(self):
        """ Get interface_type value.

            Notes:
                Can be BROADCAST or POINT_TO_POINT

                
                This attribute is named `interfaceType` in VSD API.
                
        """
        return self._interface_type

    @interface_type.setter
    def interface_type(self, value):
        """ Set interface_type value.

            Notes:
                Can be BROADCAST or POINT_TO_POINT

                
                This attribute is named `interfaceType` in VSD API.
                
        """
        self._interface_type = value

    
    @property
    def entity_scope(self):
        """ Get entity_scope value.

            Notes:
                Specify if scope of entity is Data center or Enterprise level

                
                This attribute is named `entityScope` in VSD API.
                
        """
        return self._entity_scope

    @entity_scope.setter
    def entity_scope(self, value):
        """ Set entity_scope value.

            Notes:
                Specify if scope of entity is Data center or Enterprise level

                
                This attribute is named `entityScope` in VSD API.
                
        """
        self._entity_scope = value

    
    @property
    def priority(self):
        """ Get priority value.

            Notes:
                Determines which routers are selected as the designated router and backup designated router of the area.

                
        """
        return self._priority

    @priority.setter
    def priority(self, value):
        """ Set priority value.

            Notes:
                Determines which routers are selected as the designated router and backup designated router of the area.

                
        """
        self._priority = value

    
    @property
    def associated_subnet_id(self):
        """ Get associated_subnet_id value.

            Notes:
                ID of the Subnet which is associated to the current OSPFInterface. Once the OSPF interface is created, the associated subnet ID cannot be updated. The interface must be deleted and re-created with a different subnet ID.

                
                This attribute is named `associatedSubnetID` in VSD API.
                
        """
        return self._associated_subnet_id

    @associated_subnet_id.setter
    def associated_subnet_id(self, value):
        """ Set associated_subnet_id value.

            Notes:
                ID of the Subnet which is associated to the current OSPFInterface. Once the OSPF interface is created, the associated subnet ID cannot be updated. The interface must be deleted and re-created with a different subnet ID.

                
                This attribute is named `associatedSubnetID` in VSD API.
                
        """
        self._associated_subnet_id = value

    
    @property
    def mtu(self):
        """ Get mtu value.

            Notes:
                MTU to be used by OSPF for this logical interface

                
        """
        return self._mtu

    @mtu.setter
    def mtu(self, value):
        """ Set mtu value.

            Notes:
                MTU to be used by OSPF for this logical interface

                
        """
        self._mtu = value

    
    @property
    def authentication_key(self):
        """ Get authentication_key value.

            Notes:
                The authentication key that is used on the interface.

                
                This attribute is named `authenticationKey` in VSD API.
                
        """
        return self._authentication_key

    @authentication_key.setter
    def authentication_key(self, value):
        """ Set authentication_key value.

            Notes:
                The authentication key that is used on the interface.

                
                This attribute is named `authenticationKey` in VSD API.
                
        """
        self._authentication_key = value

    
    @property
    def authentication_type(self):
        """ Get authentication_type value.

            Notes:
                Authentication Type used for this OSPFInterface

                
                This attribute is named `authenticationType` in VSD API.
                
        """
        return self._authentication_type

    @authentication_type.setter
    def authentication_type(self, value):
        """ Set authentication_type value.

            Notes:
                Authentication Type used for this OSPFInterface

                
                This attribute is named `authenticationType` in VSD API.
                
        """
        self._authentication_type = value

    
    @property
    def external_id(self):
        """ Get external_id value.

            Notes:
                External object ID. Used for integration with third party systems

                
                This attribute is named `externalID` in VSD API.
                
        """
        return self._external_id

    @external_id.setter
    def external_id(self, value):
        """ Set external_id value.

            Notes:
                External object ID. Used for integration with third party systems

                
                This attribute is named `externalID` in VSD API.
                
        """
        self._external_id = value

    

    


# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.




from .fetchers import NUMetadatasFetcher


from .fetchers import NUGlobalMetadatasFetcher


from .fetchers import NUMonitorscopesFetcher


from .fetchers import NUApplicationBindingsFetcher

from bambou import NURESTObject


class NUApplication(NURESTObject):
    """ Represents a Application in the VSD

        Notes:
            represents a application with L4/L7 classification
    """

    __rest_name__ = "application"
    __resource_name__ = "applications"

    
    ## Constants
    
    CONST_POST_CLASSIFICATION_PATH_ANY = "ANY"
    
    CONST_PROTOCOL_NONE = "NONE"
    
    CONST_PERFORMANCE_MONITOR_TYPE_FIRST_PACKET = "FIRST_PACKET"
    
    CONST_PRE_CLASSIFICATION_PATH_PRIMARY = "PRIMARY"
    
    CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
    
    CONST_PRE_CLASSIFICATION_PATH_SECONDARY = "SECONDARY"
    
    CONST_PERFORMANCE_MONITOR_TYPE_CONTINUOUS = "CONTINUOUS"
    
    CONST_OPTIMIZE_PATH_SELECTION_PACKETLOSS = "PACKETLOSS"
    
    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
    
    CONST_OPTIMIZE_PATH_SELECTION_LATENCY = "LATENCY"
    
    CONST_OPTIMIZE_PATH_SELECTION_JITTER = "JITTER"
    
    CONST_PROTOCOL_UDP = "UDP"
    
    CONST_POST_CLASSIFICATION_PATH_PRIMARY = "PRIMARY"
    
    CONST_POST_CLASSIFICATION_PATH_SECONDARY = "SECONDARY"
    
    CONST_PERFORMANCE_MONITOR_TYPE_FIRST_PACKET_AND_CONTINUOUS = "FIRST_PACKET_AND_CONTINUOUS"
    
    CONST_PROTOCOL_TCP = "TCP"
    
    CONST_PRE_CLASSIFICATION_PATH_DEFAULT = "DEFAULT"
    
    

    def __init__(self, **kwargs):
        """ Initializes a Application instance

            Notes:
                You can specify all parameters while calling this methods.
                A special argument named `data` will enable you to load the
                object from a Python dictionary

            Examples:
                >>> application = NUApplication(id=u'xxxx-xxx-xxx-xxx', name=u'Application')
                >>> application = NUApplication(data=my_dict)
        """

        super(NUApplication, self).__init__()

        # Read/Write Attributes
        
        self._dscp = None
        self._name = None
        self._bandwidth = None
        self._last_updated_by = None
        self._read_only = None
        self._performance_monitor_type = None
        self._certificate_common_name = None
        self._description = None
        self._destination_ip = None
        self._destination_port = None
        self._network_symmetry = None
        self._enable_pps = None
        self._one_way_delay = None
        self._one_way_jitter = None
        self._one_way_loss = None
        self._entity_scope = None
        self._post_classification_path = None
        self._source_ip = None
        self._source_port = None
        self._app_id = None
        self._optimize_path_selection = None
        self._pre_classification_path = None
        self._protocol = None
        self._associated_l7_application_signature_id = None
        self._ether_type = None
        self._external_id = None
        self._symmetry = None
        
        self.expose_attribute(local_name="dscp", remote_name="DSCP", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
        self.expose_attribute(local_name="bandwidth", remote_name="bandwidth", attribute_type=int, is_required=False, is_unique=False)
        self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="read_only", remote_name="readOnly", attribute_type=bool, is_required=False, is_unique=False)
        self.expose_attribute(local_name="performance_monitor_type", remote_name="performanceMonitorType", attribute_type=str, is_required=False, is_unique=False, choices=[u'CONTINUOUS', u'FIRST_PACKET', u'FIRST_PACKET_AND_CONTINUOUS'])
        self.expose_attribute(local_name="certificate_common_name", remote_name="certificateCommonName", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="destination_ip", remote_name="destinationIP", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="destination_port", remote_name="destinationPort", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="network_symmetry", remote_name="networkSymmetry", attribute_type=bool, is_required=False, is_unique=False)
        self.expose_attribute(local_name="enable_pps", remote_name="enablePPS", attribute_type=bool, is_required=False, is_unique=False)
        self.expose_attribute(local_name="one_way_delay", remote_name="oneWayDelay", attribute_type=int, is_required=False, is_unique=False)
        self.expose_attribute(local_name="one_way_jitter", remote_name="oneWayJitter", attribute_type=int, is_required=False, is_unique=False)
        self.expose_attribute(local_name="one_way_loss", remote_name="oneWayLoss", attribute_type=float, is_required=False, is_unique=False)
        self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
        self.expose_attribute(local_name="post_classification_path", remote_name="postClassificationPath", attribute_type=str, is_required=False, is_unique=False, choices=[u'ANY', u'PRIMARY', u'SECONDARY'])
        self.expose_attribute(local_name="source_ip", remote_name="sourceIP", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="source_port", remote_name="sourcePort", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="app_id", remote_name="appId", attribute_type=int, is_required=False, is_unique=False)
        self.expose_attribute(local_name="optimize_path_selection", remote_name="optimizePathSelection", attribute_type=str, is_required=False, is_unique=False, choices=[u'JITTER', u'LATENCY', u'PACKETLOSS'])
        self.expose_attribute(local_name="pre_classification_path", remote_name="preClassificationPath", attribute_type=str, is_required=False, is_unique=False, choices=[u'DEFAULT', u'PRIMARY', u'SECONDARY'])
        self.expose_attribute(local_name="protocol", remote_name="protocol", attribute_type=str, is_required=False, is_unique=False, choices=[u'NONE', u'TCP', u'UDP'])
        self.expose_attribute(local_name="associated_l7_application_signature_id", remote_name="associatedL7ApplicationSignatureID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="ether_type", remote_name="etherType", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
        self.expose_attribute(local_name="symmetry", remote_name="symmetry", attribute_type=bool, is_required=False, is_unique=False)
        

        # Fetchers
        
        
        self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
        
        
        self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
        
        
        self.monitorscopes = NUMonitorscopesFetcher.fetcher_with_object(parent_object=self, relationship="child")
        
        
        self.application_bindings = NUApplicationBindingsFetcher.fetcher_with_object(parent_object=self, relationship="member")
        

        self._compute_args(**kwargs)

    # Properties
    
    @property
    def dscp(self):
        """ Get dscp value.

            Notes:
                DSCP match condition to be set in the rule. It is either * or from 0-63.

                
                This attribute is named `DSCP` in VSD API.
                
        """
        return self._dscp

    @dscp.setter
    def dscp(self, value):
        """ Set dscp value.

            Notes:
                DSCP match condition to be set in the rule. It is either * or from 0-63.

                
                This attribute is named `DSCP` in VSD API.
                
        """
        self._dscp = value

    
    @property
    def name(self):
        """ Get name value.

            Notes:
                name of the application

                
        """
        return self._name

    @name.setter
    def name(self, value):
        """ Set name value.

            Notes:
                name of the application

                
        """
        self._name = value

    
    @property
    def bandwidth(self):
        """ Get bandwidth value.

            Notes:
                Minimum Failover Bandwidth of the application.

                
        """
        return self._bandwidth

    @bandwidth.setter
    def bandwidth(self, value):
        """ Set bandwidth value.

            Notes:
                Minimum Failover Bandwidth of the application.

                
        """
        self._bandwidth = value

    
    @property
    def last_updated_by(self):
        """ Get last_updated_by value.

            Notes:
                ID of the user who last updated the object.

                
                This attribute is named `lastUpdatedBy` in VSD API.
                
        """
        return self._last_updated_by

    @last_updated_by.setter
    def last_updated_by(self, value):
        """ Set last_updated_by value.

            Notes:
                ID of the user who last updated the object.

                
                This attribute is named `lastUpdatedBy` in VSD API.
                
        """
        self._last_updated_by = value

    
    @property
    def read_only(self):
        """ Get read_only value.

            Notes:
                determines whether this entity is read only.  Read only objects cannot be modified or deleted.

                
                This attribute is named `readOnly` in VSD API.
                
        """
        return self._read_only

    @read_only.setter
    def read_only(self, value):
        """ Set read_only value.

            Notes:
                determines whether this entity is read only.  Read only objects cannot be modified or deleted.

                
                This attribute is named `readOnly` in VSD API.
                
        """
        self._read_only = value

    
    @property
    def performance_monitor_type(self):
        """ Get performance_monitor_type value.

            Notes:
                Describes the trigger for the application.

                
                This attribute is named `performanceMonitorType` in VSD API.
                
        """
        return self._performance_monitor_type

    @performance_monitor_type.setter
    def performance_monitor_type(self, value):
        """ Set performance_monitor_type value.

            Notes:
                Describes the trigger for the application.

                
                This attribute is named `performanceMonitorType` in VSD API.
                
        """
        self._performance_monitor_type = value

    
    @property
    def certificate_common_name(self):
        """ Get certificate_common_name value.

            Notes:
                Describes the certificate common name

                
                This attribute is named `certificateCommonName` in VSD API.
                
        """
        return self._certificate_common_name

    @certificate_common_name.setter
    def certificate_common_name(self, value):
        """ Set certificate_common_name value.

            Notes:
                Describes the certificate common name

                
                This attribute is named `certificateCommonName` in VSD API.
                
        """
        self._certificate_common_name = value

    
    @property
    def description(self):
        """ Get description value.

            Notes:
                description of Application

                
        """
        return self._description

    @description.setter
    def description(self, value):
        """ Set description value.

            Notes:
                description of Application

                
        """
        self._description = value

    
    @property
    def destination_ip(self):
        """ Get destination_ip value.

            Notes:
                destination IP in CIDR format

                
                This attribute is named `destinationIP` in VSD API.
                
        """
        return self._destination_ip

    @destination_ip.setter
    def destination_ip(self, value):
        """ Set destination_ip value.

            Notes:
                destination IP in CIDR format

                
                This attribute is named `destinationIP` in VSD API.
                
        """
        self._destination_ip = value

    
    @property
    def destination_port(self):
        """ Get destination_port value.

            Notes:
                value should be either * or single port number 

                
                This attribute is named `destinationPort` in VSD API.
                
        """
        return self._destination_port

    @destination_port.setter
    def destination_port(self, value):
        """ Set destination_port value.

            Notes:
                value should be either * or single port number 

                
                This attribute is named `destinationPort` in VSD API.
                
        """
        self._destination_port = value

    
    @property
    def network_symmetry(self):
        """ Get network_symmetry value.

            Notes:
                Network symmetry flag

                
                This attribute is named `networkSymmetry` in VSD API.
                
        """
        return self._network_symmetry

    @network_symmetry.setter
    def network_symmetry(self, value):
        """ Set network_symmetry value.

            Notes:
                Network symmetry flag

                
                This attribute is named `networkSymmetry` in VSD API.
                
        """
        self._network_symmetry = value

    
    @property
    def enable_pps(self):
        """ Get enable_pps value.

            Notes:
                Enable the performance probe for this application

                
                This attribute is named `enablePPS` in VSD API.
                
        """
        return self._enable_pps

    @enable_pps.setter
    def enable_pps(self, value):
        """ Set enable_pps value.

            Notes:
                Enable the performance probe for this application

                
                This attribute is named `enablePPS` in VSD API.
                
        """
        self._enable_pps = value

    
    @property
    def one_way_delay(self):
        """ Get one_way_delay value.

            Notes:
                one way Delay

                
                This attribute is named `oneWayDelay` in VSD API.
                
        """
        return self._one_way_delay

    @one_way_delay.setter
    def one_way_delay(self, value):
        """ Set one_way_delay value.

            Notes:
                one way Delay

                
                This attribute is named `oneWayDelay` in VSD API.
                
        """
        self._one_way_delay = value

    
    @property
    def one_way_jitter(self):
        """ Get one_way_jitter value.

            Notes:
                one way Jitter

                
                This attribute is named `oneWayJitter` in VSD API.
                
        """
        return self._one_way_jitter

    @one_way_jitter.setter
    def one_way_jitter(self, value):
        """ Set one_way_jitter value.

            Notes:
                one way Jitter

                
                This attribute is named `oneWayJitter` in VSD API.
                
        """
        self._one_way_jitter = value

    
    @property
    def one_way_loss(self):
        """ Get one_way_loss value.

            Notes:
                one way loss

                
                This attribute is named `oneWayLoss` in VSD API.
                
        """
        return self._one_way_loss

    @one_way_loss.setter
    def one_way_loss(self, value):
        """ Set one_way_loss value.

            Notes:
                one way loss

                
                This attribute is named `oneWayLoss` in VSD API.
                
        """
        self._one_way_loss = value

    
    @property
    def entity_scope(self):
        """ Get entity_scope value.

            Notes:
                Specify if scope of entity is Data center or Enterprise level

                
                This attribute is named `entityScope` in VSD API.
                
        """
        return self._entity_scope

    @entity_scope.setter
    def entity_scope(self, value):
        """ Set entity_scope value.

            Notes:
                Specify if scope of entity is Data center or Enterprise level

                
                This attribute is named `entityScope` in VSD API.
                
        """
        self._entity_scope = value

    
    @property
    def post_classification_path(self):
        """ Get post_classification_path value.

            Notes:
                default set to any , possible values primary/secondary/any

                
                This attribute is named `postClassificationPath` in VSD API.
                
        """
        return self._post_classification_path

    @post_classification_path.setter
    def post_classification_path(self, value):
        """ Set post_classification_path value.

            Notes:
                default set to any , possible values primary/secondary/any

                
                This attribute is named `postClassificationPath` in VSD API.
                
        """
        self._post_classification_path = value

    
    @property
    def source_ip(self):
        """ Get source_ip value.

            Notes:
                source IP address

                
                This attribute is named `sourceIP` in VSD API.
                
        """
        return self._source_ip

    @source_ip.setter
    def source_ip(self, value):
        """ Set source_ip value.

            Notes:
                source IP address

                
                This attribute is named `sourceIP` in VSD API.
                
        """
        self._source_ip = value

    
    @property
    def source_port(self):
        """ Get source_port value.

            Notes:
                source Port ,value should be either * or single port number 

                
                This attribute is named `sourcePort` in VSD API.
                
        """
        return self._source_port

    @source_port.setter
    def source_port(self, value):
        """ Set source_port value.

            Notes:
                source Port ,value should be either * or single port number 

                
                This attribute is named `sourcePort` in VSD API.
                
        """
        self._source_port = value

    
    @property
    def app_id(self):
        """ Get app_id value.

            Notes:
                a unique 2 byte id generated when a application is created and used by VRS  for probing.

                
                This attribute is named `appId` in VSD API.
                
        """
        return self._app_id

    @app_id.setter
    def app_id(self, value):
        """ Set app_id value.

            Notes:
                a unique 2 byte id generated when a application is created and used by VRS  for probing.

                
                This attribute is named `appId` in VSD API.
                
        """
        self._app_id = value

    
    @property
    def optimize_path_selection(self):
        """ Get optimize_path_selection value.

            Notes:
                with values being Latency, Jitter, PacketLoss

                
                This attribute is named `optimizePathSelection` in VSD API.
                
        """
        return self._optimize_path_selection

    @optimize_path_selection.setter
    def optimize_path_selection(self, value):
        """ Set optimize_path_selection value.

            Notes:
                with values being Latency, Jitter, PacketLoss

                
                This attribute is named `optimizePathSelection` in VSD API.
                
        """
        self._optimize_path_selection = value

    
    @property
    def pre_classification_path(self):
        """ Get pre_classification_path value.

            Notes:
                default set to primary , possible values primary/secondary

                
                This attribute is named `preClassificationPath` in VSD API.
                
        """
        return self._pre_classification_path

    @pre_classification_path.setter
    def pre_classification_path(self, value):
        """ Set pre_classification_path value.

            Notes:
                default set to primary , possible values primary/secondary

                
                This attribute is named `preClassificationPath` in VSD API.
                
        """
        self._pre_classification_path = value

    
    @property
    def protocol(self):
        """ Get protocol value.

            Notes:
                Protocol number that must be matched

                
        """
        return self._protocol

    @protocol.setter
    def protocol(self, value):
        """ Set protocol value.

            Notes:
                Protocol number that must be matched

                
        """
        self._protocol = value

    
    @property
    def associated_l7_application_signature_id(self):
        """ Get associated_l7_application_signature_id value.

            Notes:
                associated Layer7 Application Type ID

                
                This attribute is named `associatedL7ApplicationSignatureID` in VSD API.
                
        """
        return self._associated_l7_application_signature_id

    @associated_l7_application_signature_id.setter
    def associated_l7_application_signature_id(self, value):
        """ Set associated_l7_application_signature_id value.

            Notes:
                associated Layer7 Application Type ID

                
                This attribute is named `associatedL7ApplicationSignatureID` in VSD API.
                
        """
        self._associated_l7_application_signature_id = value

    
    @property
    def ether_type(self):
        """ Get ether_type value.

            Notes:
                Ether type of the packet to be matched. etherType can be * or a valid hexadecimal value

                
                This attribute is named `etherType` in VSD API.
                
        """
        return self._ether_type

    @ether_type.setter
    def ether_type(self, value):
        """ Set ether_type value.

            Notes:
                Ether type of the packet to be matched. etherType can be * or a valid hexadecimal value

                
                This attribute is named `etherType` in VSD API.
                
        """
        self._ether_type = value

    
    @property
    def external_id(self):
        """ Get external_id value.

            Notes:
                External object ID. Used for integration with third party systems

                
                This attribute is named `externalID` in VSD API.
                
        """
        return self._external_id

    @external_id.setter
    def external_id(self, value):
        """ Set external_id value.

            Notes:
                External object ID. Used for integration with third party systems

                
                This attribute is named `externalID` in VSD API.
                
        """
        self._external_id = value

    
    @property
    def symmetry(self):
        """ Get symmetry value.

            Notes:
                Maintain path symmetry during SLA violation

                
        """
        return self._symmetry

    @symmetry.setter
    def symmetry(self, value):
        """ Set symmetry value.

            Notes:
                Maintain path symmetry during SLA violation

                
        """
        self._symmetry = value

    

    